import { AuthenticationServiceBasicValidation, DeviceServiceBasicValidation, ExperimentServiceBasicValidation, FederationServiceBasicValidation, BookingServiceBasicValidation } from "./basicValidation.js";
/**
 * Namespace containing the request validation functions for the Authentication Service.
 */
export var AuthenticationServiceRequestValidation;
(function (AuthenticationServiceRequestValidation) {
    /**
     * This function validates the inputs to login()
     */
    function validateLoginInput(body) {
        if (!AuthenticationServiceBasicValidation.validateLoginBodyRequest(body)) {
            validateLoginInput.errors = AuthenticationServiceBasicValidation.validateLoginBodyRequest.errors;
            return false;
        }
        return true;
    }
    AuthenticationServiceRequestValidation.validateLoginInput = validateLoginInput;
    /**
     * This function validates the outputs of login()
     */
    function validateLoginOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 201) {
            if (!AuthenticationServiceBasicValidation.validateLoginResponse201Response(response.body)) {
                validateLoginOutput.errors = AuthenticationServiceBasicValidation.validateLoginResponse201Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateLoginOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    AuthenticationServiceRequestValidation.validateLoginOutput = validateLoginOutput;
    /**
     * This function validates the inputs to logout()
     */
    function validateLogoutInput(body) {
        if (!AuthenticationServiceBasicValidation.validateLogoutBodyRequest(body)) {
            validateLogoutInput.errors = AuthenticationServiceBasicValidation.validateLogoutBodyRequest.errors;
            return false;
        }
        return true;
    }
    AuthenticationServiceRequestValidation.validateLogoutInput = validateLogoutInput;
    /**
     * This function validates the outputs of logout()
     */
    function validateLogoutOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 204) {
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateLogoutOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    AuthenticationServiceRequestValidation.validateLogoutOutput = validateLogoutOutput;
    /**
     * This function validates the inputs to listUsers()
     */
    function validateListUsersInput(parameters) {
        if (parameters) {
            if (!AuthenticationServiceBasicValidation.validateUsernameRequest(parameters["username"])
                && parameters['username'] !== undefined) {
                validateListUsersInput.errors = AuthenticationServiceBasicValidation.validateUsernameRequest.errors;
                return false;
            }
        }
        else {
            if (parameters !== undefined) {
                return false;
            }
        }
        return true;
    }
    AuthenticationServiceRequestValidation.validateListUsersInput = validateListUsersInput;
    /**
     * This function validates the outputs of listUsers()
     */
    function validateListUsersOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!AuthenticationServiceBasicValidation.validateListUsersResponse200Response(response.body)) {
                validateListUsersOutput.errors = AuthenticationServiceBasicValidation.validateListUsersResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateListUsersOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    AuthenticationServiceRequestValidation.validateListUsersOutput = validateListUsersOutput;
    /**
     * This function validates the inputs to createUser()
     */
    function validateCreateUserInput(body) {
        if (!AuthenticationServiceBasicValidation.validateCreateUserBodyRequest(body)) {
            validateCreateUserInput.errors = AuthenticationServiceBasicValidation.validateCreateUserBodyRequest.errors;
            return false;
        }
        return true;
    }
    AuthenticationServiceRequestValidation.validateCreateUserInput = validateCreateUserInput;
    /**
     * This function validates the outputs of createUser()
     */
    function validateCreateUserOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 201) {
            if (!AuthenticationServiceBasicValidation.validateCreateUserResponse201Response(response.body)) {
                validateCreateUserOutput.errors = AuthenticationServiceBasicValidation.validateCreateUserResponse201Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateCreateUserOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    AuthenticationServiceRequestValidation.validateCreateUserOutput = validateCreateUserOutput;
    /**
     * This function validates the inputs to getUser()
     */
    function validateGetUserInput(parameters) {
        if (parameters) {
            if (!AuthenticationServiceBasicValidation.validateUserIdRequest(parameters["user_id"])) {
                validateGetUserInput.errors = AuthenticationServiceBasicValidation.validateUserIdRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        return true;
    }
    AuthenticationServiceRequestValidation.validateGetUserInput = validateGetUserInput;
    /**
     * This function validates the outputs of getUser()
     */
    function validateGetUserOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!AuthenticationServiceBasicValidation.validateGetUserResponse200Response(response.body)) {
                validateGetUserOutput.errors = AuthenticationServiceBasicValidation.validateGetUserResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateGetUserOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    AuthenticationServiceRequestValidation.validateGetUserOutput = validateGetUserOutput;
    /**
     * This function validates the inputs to updateUser()
     */
    function validateUpdateUserInput(parameters, body) {
        if (parameters) {
            if (!AuthenticationServiceBasicValidation.validateUserIdRequest(parameters["user_id"])) {
                validateUpdateUserInput.errors = AuthenticationServiceBasicValidation.validateUserIdRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        if (!AuthenticationServiceBasicValidation.validateUpdateUserBodyRequest(body)) {
            validateUpdateUserInput.errors = AuthenticationServiceBasicValidation.validateUpdateUserBodyRequest.errors;
            return false;
        }
        return true;
    }
    AuthenticationServiceRequestValidation.validateUpdateUserInput = validateUpdateUserInput;
    /**
     * This function validates the outputs of updateUser()
     */
    function validateUpdateUserOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!AuthenticationServiceBasicValidation.validateUpdateUserResponse200Response(response.body)) {
                validateUpdateUserOutput.errors = AuthenticationServiceBasicValidation.validateUpdateUserResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateUpdateUserOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    AuthenticationServiceRequestValidation.validateUpdateUserOutput = validateUpdateUserOutput;
    /**
     * This function validates the inputs to deleteUser()
     */
    function validateDeleteUserInput(parameters) {
        if (parameters) {
            if (!AuthenticationServiceBasicValidation.validateUserIdRequest(parameters["user_id"])) {
                validateDeleteUserInput.errors = AuthenticationServiceBasicValidation.validateUserIdRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        return true;
    }
    AuthenticationServiceRequestValidation.validateDeleteUserInput = validateDeleteUserInput;
    /**
     * This function validates the outputs of deleteUser()
     */
    function validateDeleteUserOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 204) {
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateDeleteUserOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    AuthenticationServiceRequestValidation.validateDeleteUserOutput = validateDeleteUserOutput;
    /**
     * This function validates the inputs to getIdentity()
     */
    function validateGetIdentityInput() {
        return true;
    }
    AuthenticationServiceRequestValidation.validateGetIdentityInput = validateGetIdentityInput;
    /**
     * This function validates the outputs of getIdentity()
     */
    function validateGetIdentityOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!AuthenticationServiceBasicValidation.validateGetIdentityResponse200Response(response.body)) {
                validateGetIdentityOutput.errors = AuthenticationServiceBasicValidation.validateGetIdentityResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateGetIdentityOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    AuthenticationServiceRequestValidation.validateGetIdentityOutput = validateGetIdentityOutput;
    /**
     * This function validates the inputs to updateIdentity()
     */
    function validateUpdateIdentityInput(body) {
        if (body === undefined) {
            return true;
        }
        if (!AuthenticationServiceBasicValidation.validateUpdateIdentityBodyRequest(body)) {
            validateUpdateIdentityInput.errors = AuthenticationServiceBasicValidation.validateUpdateIdentityBodyRequest.errors;
            return false;
        }
        return true;
    }
    AuthenticationServiceRequestValidation.validateUpdateIdentityInput = validateUpdateIdentityInput;
    /**
     * This function validates the outputs of updateIdentity()
     */
    function validateUpdateIdentityOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!AuthenticationServiceBasicValidation.validateUpdateIdentityResponse200Response(response.body)) {
                validateUpdateIdentityOutput.errors = AuthenticationServiceBasicValidation.validateUpdateIdentityResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateUpdateIdentityOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    AuthenticationServiceRequestValidation.validateUpdateIdentityOutput = validateUpdateIdentityOutput;
    /**
     * This function validates the inputs to createToken()
     */
    function validateCreateTokenInput(body) {
        if (!AuthenticationServiceBasicValidation.validateCreateTokenBodyRequest(body)) {
            validateCreateTokenInput.errors = AuthenticationServiceBasicValidation.validateCreateTokenBodyRequest.errors;
            return false;
        }
        return true;
    }
    AuthenticationServiceRequestValidation.validateCreateTokenInput = validateCreateTokenInput;
    /**
     * This function validates the outputs of createToken()
     */
    function validateCreateTokenOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 201) {
            if (!AuthenticationServiceBasicValidation.validateCreateTokenResponse201Response(response.body)) {
                validateCreateTokenOutput.errors = AuthenticationServiceBasicValidation.validateCreateTokenResponse201Response.errors;
                return false;
            }
            return true;
        }
        validateCreateTokenOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    AuthenticationServiceRequestValidation.validateCreateTokenOutput = validateCreateTokenOutput;
})(AuthenticationServiceRequestValidation || (AuthenticationServiceRequestValidation = {}));
/**
 * Namespace containing the request validation functions for the Device Service.
 */
export var DeviceServiceRequestValidation;
(function (DeviceServiceRequestValidation) {
    /**
     * This function validates the inputs to listDevices()
     */
    function validateListDevicesInput() {
        return true;
    }
    DeviceServiceRequestValidation.validateListDevicesInput = validateListDevicesInput;
    /**
     * This function validates the outputs of listDevices()
     */
    function validateListDevicesOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!DeviceServiceBasicValidation.validateListDevicesResponse200Response(response.body)) {
                validateListDevicesOutput.errors = DeviceServiceBasicValidation.validateListDevicesResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateListDevicesOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    DeviceServiceRequestValidation.validateListDevicesOutput = validateListDevicesOutput;
    /**
     * This function validates the inputs to createDevice()
     */
    function validateCreateDeviceInput(parameters, body) {
        if (parameters) {
            if (!DeviceServiceBasicValidation.validateChangedUrlRequest(parameters["changedUrl"])
                && parameters['changedUrl'] !== undefined) {
                validateCreateDeviceInput.errors = DeviceServiceBasicValidation.validateChangedUrlRequest.errors;
                return false;
            }
        }
        else {
            if (parameters !== undefined) {
                return false;
            }
        }
        if (!DeviceServiceBasicValidation.validateCreateDeviceBodyRequest(body)) {
            validateCreateDeviceInput.errors = DeviceServiceBasicValidation.validateCreateDeviceBodyRequest.errors;
            return false;
        }
        return true;
    }
    DeviceServiceRequestValidation.validateCreateDeviceInput = validateCreateDeviceInput;
    /**
     * This function validates the outputs of createDevice()
     */
    function validateCreateDeviceOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 201) {
            if (!DeviceServiceBasicValidation.validateCreateDeviceResponse201Response(response.body)) {
                validateCreateDeviceOutput.errors = DeviceServiceBasicValidation.validateCreateDeviceResponse201Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateCreateDeviceOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    DeviceServiceRequestValidation.validateCreateDeviceOutput = validateCreateDeviceOutput;
    /**
     * This function validates the inputs to getDevice()
     */
    function validateGetDeviceInput(parameters) {
        if (parameters) {
            if (!DeviceServiceBasicValidation.validateDeviceIdRequest(parameters["device_id"])) {
                validateGetDeviceInput.errors = DeviceServiceBasicValidation.validateDeviceIdRequest.errors;
                return false;
            }
            if (!DeviceServiceBasicValidation.validateFlatGroupRequest(parameters["flat_group"])
                && parameters['flat_group'] !== undefined) {
                validateGetDeviceInput.errors = DeviceServiceBasicValidation.validateFlatGroupRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        return true;
    }
    DeviceServiceRequestValidation.validateGetDeviceInput = validateGetDeviceInput;
    /**
     * This function validates the outputs of getDevice()
     */
    function validateGetDeviceOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!DeviceServiceBasicValidation.validateGetDeviceResponse200Response(response.body)) {
                validateGetDeviceOutput.errors = DeviceServiceBasicValidation.validateGetDeviceResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateGetDeviceOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    DeviceServiceRequestValidation.validateGetDeviceOutput = validateGetDeviceOutput;
    /**
     * This function validates the inputs to updateDevice()
     */
    function validateUpdateDeviceInput(parameters, body) {
        if (parameters) {
            if (!DeviceServiceBasicValidation.validateDeviceIdRequest(parameters["device_id"])) {
                validateUpdateDeviceInput.errors = DeviceServiceBasicValidation.validateDeviceIdRequest.errors;
                return false;
            }
            if (!DeviceServiceBasicValidation.validateChangedUrlRequest(parameters["changedUrl"])
                && parameters['changedUrl'] !== undefined) {
                validateUpdateDeviceInput.errors = DeviceServiceBasicValidation.validateChangedUrlRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        if (body === undefined) {
            return true;
        }
        if (!DeviceServiceBasicValidation.validateUpdateDeviceBodyRequest(body)) {
            validateUpdateDeviceInput.errors = DeviceServiceBasicValidation.validateUpdateDeviceBodyRequest.errors;
            return false;
        }
        return true;
    }
    DeviceServiceRequestValidation.validateUpdateDeviceInput = validateUpdateDeviceInput;
    /**
     * This function validates the outputs of updateDevice()
     */
    function validateUpdateDeviceOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!DeviceServiceBasicValidation.validateUpdateDeviceResponse200Response(response.body)) {
                validateUpdateDeviceOutput.errors = DeviceServiceBasicValidation.validateUpdateDeviceResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateUpdateDeviceOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    DeviceServiceRequestValidation.validateUpdateDeviceOutput = validateUpdateDeviceOutput;
    /**
     * This function validates the inputs to deleteDevice()
     */
    function validateDeleteDeviceInput(parameters) {
        if (parameters) {
            if (!DeviceServiceBasicValidation.validateDeviceIdRequest(parameters["device_id"])) {
                validateDeleteDeviceInput.errors = DeviceServiceBasicValidation.validateDeviceIdRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        return true;
    }
    DeviceServiceRequestValidation.validateDeleteDeviceInput = validateDeleteDeviceInput;
    /**
     * This function validates the outputs of deleteDevice()
     */
    function validateDeleteDeviceOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 204) {
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateDeleteDeviceOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    DeviceServiceRequestValidation.validateDeleteDeviceOutput = validateDeleteDeviceOutput;
    /**
     * This function validates the inputs to instantiateDevice()
     */
    function validateInstantiateDeviceInput(parameters) {
        if (parameters) {
            if (!DeviceServiceBasicValidation.validateDeviceIdRequest(parameters["device_id"])) {
                validateInstantiateDeviceInput.errors = DeviceServiceBasicValidation.validateDeviceIdRequest.errors;
                return false;
            }
            if (!DeviceServiceBasicValidation.validateChangedUrlRequest(parameters["changedUrl"])
                && parameters['changedUrl'] !== undefined) {
                validateInstantiateDeviceInput.errors = DeviceServiceBasicValidation.validateChangedUrlRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        return true;
    }
    DeviceServiceRequestValidation.validateInstantiateDeviceInput = validateInstantiateDeviceInput;
    /**
     * This function validates the outputs of instantiateDevice()
     */
    function validateInstantiateDeviceOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 201) {
            if (!DeviceServiceBasicValidation.validateInstantiateDeviceResponse201Response(response.body)) {
                validateInstantiateDeviceOutput.errors = DeviceServiceBasicValidation.validateInstantiateDeviceResponse201Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateInstantiateDeviceOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    DeviceServiceRequestValidation.validateInstantiateDeviceOutput = validateInstantiateDeviceOutput;
    /**
     * This function validates the inputs to getDeviceAvailability()
     */
    function validateGetDeviceAvailabilityInput(parameters) {
        if (parameters) {
            if (!DeviceServiceBasicValidation.validateDeviceIdRequest(parameters["device_id"])) {
                validateGetDeviceAvailabilityInput.errors = DeviceServiceBasicValidation.validateDeviceIdRequest.errors;
                return false;
            }
            if (!DeviceServiceBasicValidation.validateStartTimeRequest(parameters["startTime"])
                && parameters['startTime'] !== undefined) {
                validateGetDeviceAvailabilityInput.errors = DeviceServiceBasicValidation.validateStartTimeRequest.errors;
                return false;
            }
            if (!DeviceServiceBasicValidation.validateEndTimeRequest(parameters["endTime"])
                && parameters['endTime'] !== undefined) {
                validateGetDeviceAvailabilityInput.errors = DeviceServiceBasicValidation.validateEndTimeRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        return true;
    }
    DeviceServiceRequestValidation.validateGetDeviceAvailabilityInput = validateGetDeviceAvailabilityInput;
    /**
     * This function validates the outputs of getDeviceAvailability()
     */
    function validateGetDeviceAvailabilityOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!DeviceServiceBasicValidation.validateGetDeviceAvailabilityResponse200Response(response.body)) {
                validateGetDeviceAvailabilityOutput.errors = DeviceServiceBasicValidation.validateGetDeviceAvailabilityResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateGetDeviceAvailabilityOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    DeviceServiceRequestValidation.validateGetDeviceAvailabilityOutput = validateGetDeviceAvailabilityOutput;
    /**
     * This function validates the inputs to deleteDeviceAvailabilityRules()
     */
    function validateDeleteDeviceAvailabilityRulesInput(parameters) {
        if (parameters) {
            if (!DeviceServiceBasicValidation.validateDeviceIdRequest(parameters["device_id"])) {
                validateDeleteDeviceAvailabilityRulesInput.errors = DeviceServiceBasicValidation.validateDeviceIdRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        return true;
    }
    DeviceServiceRequestValidation.validateDeleteDeviceAvailabilityRulesInput = validateDeleteDeviceAvailabilityRulesInput;
    /**
     * This function validates the outputs of deleteDeviceAvailabilityRules()
     */
    function validateDeleteDeviceAvailabilityRulesOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 204) {
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateDeleteDeviceAvailabilityRulesOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    DeviceServiceRequestValidation.validateDeleteDeviceAvailabilityRulesOutput = validateDeleteDeviceAvailabilityRulesOutput;
    /**
     * This function validates the inputs to addDeviceAvailabilityRules()
     */
    function validateAddDeviceAvailabilityRulesInput(parameters, body) {
        if (parameters) {
            if (!DeviceServiceBasicValidation.validateDeviceIdRequest(parameters["device_id"])) {
                validateAddDeviceAvailabilityRulesInput.errors = DeviceServiceBasicValidation.validateDeviceIdRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        if (body === undefined) {
            return true;
        }
        if (!DeviceServiceBasicValidation.validateAddDeviceAvailabilityRulesBodyRequest(body)) {
            validateAddDeviceAvailabilityRulesInput.errors = DeviceServiceBasicValidation.validateAddDeviceAvailabilityRulesBodyRequest.errors;
            return false;
        }
        return true;
    }
    DeviceServiceRequestValidation.validateAddDeviceAvailabilityRulesInput = validateAddDeviceAvailabilityRulesInput;
    /**
     * This function validates the outputs of addDeviceAvailabilityRules()
     */
    function validateAddDeviceAvailabilityRulesOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!DeviceServiceBasicValidation.validateAddDeviceAvailabilityRulesResponse200Response(response.body)) {
                validateAddDeviceAvailabilityRulesOutput.errors = DeviceServiceBasicValidation.validateAddDeviceAvailabilityRulesResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateAddDeviceAvailabilityRulesOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    DeviceServiceRequestValidation.validateAddDeviceAvailabilityRulesOutput = validateAddDeviceAvailabilityRulesOutput;
    /**
     * This function validates the inputs to createWebsocketToken()
     */
    function validateCreateWebsocketTokenInput(parameters) {
        if (parameters) {
            if (!DeviceServiceBasicValidation.validateDeviceIdRequest(parameters["device_id"])) {
                validateCreateWebsocketTokenInput.errors = DeviceServiceBasicValidation.validateDeviceIdRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        return true;
    }
    DeviceServiceRequestValidation.validateCreateWebsocketTokenInput = validateCreateWebsocketTokenInput;
    /**
     * This function validates the outputs of createWebsocketToken()
     */
    function validateCreateWebsocketTokenOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!DeviceServiceBasicValidation.validateCreateWebsocketTokenResponse200Response(response.body)) {
                validateCreateWebsocketTokenOutput.errors = DeviceServiceBasicValidation.validateCreateWebsocketTokenResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateCreateWebsocketTokenOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    DeviceServiceRequestValidation.validateCreateWebsocketTokenOutput = validateCreateWebsocketTokenOutput;
    /**
     * This function validates the inputs to sendSignalingMessage()
     */
    function validateSendSignalingMessageInput(parameters, body) {
        if (parameters) {
            if (!DeviceServiceBasicValidation.validateDeviceIdRequest(parameters["device_id"])) {
                validateSendSignalingMessageInput.errors = DeviceServiceBasicValidation.validateDeviceIdRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        if (!DeviceServiceBasicValidation.validateSendSignalingMessageBodyRequest(body)) {
            validateSendSignalingMessageInput.errors = DeviceServiceBasicValidation.validateSendSignalingMessageBodyRequest.errors;
            return false;
        }
        return true;
    }
    DeviceServiceRequestValidation.validateSendSignalingMessageInput = validateSendSignalingMessageInput;
    /**
     * This function validates the outputs of sendSignalingMessage()
     */
    function validateSendSignalingMessageOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateSendSignalingMessageOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    DeviceServiceRequestValidation.validateSendSignalingMessageOutput = validateSendSignalingMessageOutput;
    /**
     * This function validates the inputs to listPeerconnections()
     */
    function validateListPeerconnectionsInput() {
        return true;
    }
    DeviceServiceRequestValidation.validateListPeerconnectionsInput = validateListPeerconnectionsInput;
    /**
     * This function validates the outputs of listPeerconnections()
     */
    function validateListPeerconnectionsOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!DeviceServiceBasicValidation.validateListPeerconnectionsResponse200Response(response.body)) {
                validateListPeerconnectionsOutput.errors = DeviceServiceBasicValidation.validateListPeerconnectionsResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateListPeerconnectionsOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    DeviceServiceRequestValidation.validateListPeerconnectionsOutput = validateListPeerconnectionsOutput;
    /**
     * This function validates the inputs to createPeerconnection()
     */
    function validateCreatePeerconnectionInput(parameters, body) {
        if (parameters) {
            if (!DeviceServiceBasicValidation.validateClosedUrlRequest(parameters["closedUrl"])
                && parameters['closedUrl'] !== undefined) {
                validateCreatePeerconnectionInput.errors = DeviceServiceBasicValidation.validateClosedUrlRequest.errors;
                return false;
            }
            if (!DeviceServiceBasicValidation.validateStatusChangedUrlRequest(parameters["statusChangedUrl"])
                && parameters['statusChangedUrl'] !== undefined) {
                validateCreatePeerconnectionInput.errors = DeviceServiceBasicValidation.validateStatusChangedUrlRequest.errors;
                return false;
            }
        }
        else {
            if (parameters !== undefined) {
                return false;
            }
        }
        if (!DeviceServiceBasicValidation.validateCreatePeerconnectionBodyRequest(body)) {
            validateCreatePeerconnectionInput.errors = DeviceServiceBasicValidation.validateCreatePeerconnectionBodyRequest.errors;
            return false;
        }
        return true;
    }
    DeviceServiceRequestValidation.validateCreatePeerconnectionInput = validateCreatePeerconnectionInput;
    /**
     * This function validates the outputs of createPeerconnection()
     */
    function validateCreatePeerconnectionOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 201) {
            if (!DeviceServiceBasicValidation.validateCreatePeerconnectionResponse201Response(response.body)) {
                validateCreatePeerconnectionOutput.errors = DeviceServiceBasicValidation.validateCreatePeerconnectionResponse201Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 202) {
            if (!DeviceServiceBasicValidation.validateCreatePeerconnectionResponse202Response(response.body)) {
                validateCreatePeerconnectionOutput.errors = DeviceServiceBasicValidation.validateCreatePeerconnectionResponse202Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateCreatePeerconnectionOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    DeviceServiceRequestValidation.validateCreatePeerconnectionOutput = validateCreatePeerconnectionOutput;
    /**
     * This function validates the inputs to getPeerconnection()
     */
    function validateGetPeerconnectionInput(parameters) {
        if (parameters) {
            if (!DeviceServiceBasicValidation.validatePeerconnectionIdRequest(parameters["peerconnection_id"])) {
                validateGetPeerconnectionInput.errors = DeviceServiceBasicValidation.validatePeerconnectionIdRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        return true;
    }
    DeviceServiceRequestValidation.validateGetPeerconnectionInput = validateGetPeerconnectionInput;
    /**
     * This function validates the outputs of getPeerconnection()
     */
    function validateGetPeerconnectionOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!DeviceServiceBasicValidation.validateGetPeerconnectionResponse200Response(response.body)) {
                validateGetPeerconnectionOutput.errors = DeviceServiceBasicValidation.validateGetPeerconnectionResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateGetPeerconnectionOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    DeviceServiceRequestValidation.validateGetPeerconnectionOutput = validateGetPeerconnectionOutput;
    /**
     * This function validates the inputs to deletePeerconnection()
     */
    function validateDeletePeerconnectionInput(parameters) {
        if (parameters) {
            if (!DeviceServiceBasicValidation.validatePeerconnectionIdRequest(parameters["peerconnection_id"])) {
                validateDeletePeerconnectionInput.errors = DeviceServiceBasicValidation.validatePeerconnectionIdRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        return true;
    }
    DeviceServiceRequestValidation.validateDeletePeerconnectionInput = validateDeletePeerconnectionInput;
    /**
     * This function validates the outputs of deletePeerconnection()
     */
    function validateDeletePeerconnectionOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 202) {
            return true;
        }
        if (response.status === 204) {
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateDeletePeerconnectionOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    DeviceServiceRequestValidation.validateDeletePeerconnectionOutput = validateDeletePeerconnectionOutput;
    /**
     * This function validates the inputs to patchPeerconnectionDeviceStatus()
     */
    function validatePatchPeerconnectionDeviceStatusInput(parameters, body) {
        if (parameters) {
            if (!DeviceServiceBasicValidation.validatePeerconnectionIdRequest(parameters["peerconnection_id"])) {
                validatePatchPeerconnectionDeviceStatusInput.errors = DeviceServiceBasicValidation.validatePeerconnectionIdRequest.errors;
                return false;
            }
            if (!DeviceServiceBasicValidation.validateDeviceUrlRequest(parameters["device_url"])) {
                validatePatchPeerconnectionDeviceStatusInput.errors = DeviceServiceBasicValidation.validateDeviceUrlRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        if (!DeviceServiceBasicValidation.validatePatchPeerconnectionDeviceStatusBodyRequest(body)) {
            validatePatchPeerconnectionDeviceStatusInput.errors = DeviceServiceBasicValidation.validatePatchPeerconnectionDeviceStatusBodyRequest.errors;
            return false;
        }
        return true;
    }
    DeviceServiceRequestValidation.validatePatchPeerconnectionDeviceStatusInput = validatePatchPeerconnectionDeviceStatusInput;
    /**
     * This function validates the outputs of patchPeerconnectionDeviceStatus()
     */
    function validatePatchPeerconnectionDeviceStatusOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 204) {
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validatePatchPeerconnectionDeviceStatusOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    DeviceServiceRequestValidation.validatePatchPeerconnectionDeviceStatusOutput = validatePatchPeerconnectionDeviceStatusOutput;
})(DeviceServiceRequestValidation || (DeviceServiceRequestValidation = {}));
/**
 * Namespace containing the request validation functions for the Experiment Service.
 */
export var ExperimentServiceRequestValidation;
(function (ExperimentServiceRequestValidation) {
    /**
     * This function validates the inputs to listExperiments()
     */
    function validateListExperimentsInput(parameters) {
        if (parameters) {
            if (!ExperimentServiceBasicValidation.validateExperimentStatusRequest(parameters["experimentStatus"])
                && parameters['experimentStatus'] !== undefined) {
                validateListExperimentsInput.errors = ExperimentServiceBasicValidation.validateExperimentStatusRequest.errors;
                return false;
            }
        }
        else {
            if (parameters !== undefined) {
                return false;
            }
        }
        return true;
    }
    ExperimentServiceRequestValidation.validateListExperimentsInput = validateListExperimentsInput;
    /**
     * This function validates the outputs of listExperiments()
     */
    function validateListExperimentsOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!ExperimentServiceBasicValidation.validateListExperimentsResponse200Response(response.body)) {
                validateListExperimentsOutput.errors = ExperimentServiceBasicValidation.validateListExperimentsResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateListExperimentsOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    ExperimentServiceRequestValidation.validateListExperimentsOutput = validateListExperimentsOutput;
    /**
     * This function validates the inputs to createExperiment()
     */
    function validateCreateExperimentInput(parameters, body) {
        if (parameters) {
            if (!ExperimentServiceBasicValidation.validateChangedURLRequest(parameters["changedURL"])
                && parameters['changedURL'] !== undefined) {
                validateCreateExperimentInput.errors = ExperimentServiceBasicValidation.validateChangedURLRequest.errors;
                return false;
            }
        }
        else {
            if (parameters !== undefined) {
                return false;
            }
        }
        if (!ExperimentServiceBasicValidation.validateCreateExperimentBodyRequest(body)) {
            validateCreateExperimentInput.errors = ExperimentServiceBasicValidation.validateCreateExperimentBodyRequest.errors;
            return false;
        }
        return true;
    }
    ExperimentServiceRequestValidation.validateCreateExperimentInput = validateCreateExperimentInput;
    /**
     * This function validates the outputs of createExperiment()
     */
    function validateCreateExperimentOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 201) {
            if (!ExperimentServiceBasicValidation.validateCreateExperimentResponse201Response(response.body)) {
                validateCreateExperimentOutput.errors = ExperimentServiceBasicValidation.validateCreateExperimentResponse201Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 202) {
            if (!ExperimentServiceBasicValidation.validateCreateExperimentResponse202Response(response.body)) {
                validateCreateExperimentOutput.errors = ExperimentServiceBasicValidation.validateCreateExperimentResponse202Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateCreateExperimentOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    ExperimentServiceRequestValidation.validateCreateExperimentOutput = validateCreateExperimentOutput;
    /**
     * This function validates the inputs to getExperiment()
     */
    function validateGetExperimentInput(parameters) {
        if (parameters) {
            if (!ExperimentServiceBasicValidation.validateExperimentIdRequest(parameters["experiment_id"])) {
                validateGetExperimentInput.errors = ExperimentServiceBasicValidation.validateExperimentIdRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        return true;
    }
    ExperimentServiceRequestValidation.validateGetExperimentInput = validateGetExperimentInput;
    /**
     * This function validates the outputs of getExperiment()
     */
    function validateGetExperimentOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!ExperimentServiceBasicValidation.validateGetExperimentResponse200Response(response.body)) {
                validateGetExperimentOutput.errors = ExperimentServiceBasicValidation.validateGetExperimentResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateGetExperimentOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    ExperimentServiceRequestValidation.validateGetExperimentOutput = validateGetExperimentOutput;
    /**
     * This function validates the inputs to updateExperiment()
     */
    function validateUpdateExperimentInput(parameters, body) {
        if (parameters) {
            if (!ExperimentServiceBasicValidation.validateExperimentIdRequest(parameters["experiment_id"])) {
                validateUpdateExperimentInput.errors = ExperimentServiceBasicValidation.validateExperimentIdRequest.errors;
                return false;
            }
            if (!ExperimentServiceBasicValidation.validateChangedURLRequest(parameters["changedURL"])
                && parameters['changedURL'] !== undefined) {
                validateUpdateExperimentInput.errors = ExperimentServiceBasicValidation.validateChangedURLRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        if (body === undefined) {
            return true;
        }
        if (!ExperimentServiceBasicValidation.validateUpdateExperimentBodyRequest(body)) {
            validateUpdateExperimentInput.errors = ExperimentServiceBasicValidation.validateUpdateExperimentBodyRequest.errors;
            return false;
        }
        return true;
    }
    ExperimentServiceRequestValidation.validateUpdateExperimentInput = validateUpdateExperimentInput;
    /**
     * This function validates the outputs of updateExperiment()
     */
    function validateUpdateExperimentOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!ExperimentServiceBasicValidation.validateUpdateExperimentResponse200Response(response.body)) {
                validateUpdateExperimentOutput.errors = ExperimentServiceBasicValidation.validateUpdateExperimentResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 202) {
            if (!ExperimentServiceBasicValidation.validateUpdateExperimentResponse202Response(response.body)) {
                validateUpdateExperimentOutput.errors = ExperimentServiceBasicValidation.validateUpdateExperimentResponse202Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateUpdateExperimentOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    ExperimentServiceRequestValidation.validateUpdateExperimentOutput = validateUpdateExperimentOutput;
    /**
     * This function validates the inputs to deleteExperiment()
     */
    function validateDeleteExperimentInput(parameters) {
        if (parameters) {
            if (!ExperimentServiceBasicValidation.validateExperimentIdRequest(parameters["experiment_id"])) {
                validateDeleteExperimentInput.errors = ExperimentServiceBasicValidation.validateExperimentIdRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        return true;
    }
    ExperimentServiceRequestValidation.validateDeleteExperimentInput = validateDeleteExperimentInput;
    /**
     * This function validates the outputs of deleteExperiment()
     */
    function validateDeleteExperimentOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 204) {
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateDeleteExperimentOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    ExperimentServiceRequestValidation.validateDeleteExperimentOutput = validateDeleteExperimentOutput;
    /**
     * This function validates the inputs to listTemplate()
     */
    function validateListTemplateInput() {
        return true;
    }
    ExperimentServiceRequestValidation.validateListTemplateInput = validateListTemplateInput;
    /**
     * This function validates the outputs of listTemplate()
     */
    function validateListTemplateOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!ExperimentServiceBasicValidation.validateListTemplateResponse200Response(response.body)) {
                validateListTemplateOutput.errors = ExperimentServiceBasicValidation.validateListTemplateResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateListTemplateOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    ExperimentServiceRequestValidation.validateListTemplateOutput = validateListTemplateOutput;
    /**
     * This function validates the inputs to createTemplate()
     */
    function validateCreateTemplateInput(body) {
        if (!ExperimentServiceBasicValidation.validateCreateTemplateBodyRequest(body)) {
            validateCreateTemplateInput.errors = ExperimentServiceBasicValidation.validateCreateTemplateBodyRequest.errors;
            return false;
        }
        return true;
    }
    ExperimentServiceRequestValidation.validateCreateTemplateInput = validateCreateTemplateInput;
    /**
     * This function validates the outputs of createTemplate()
     */
    function validateCreateTemplateOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 201) {
            if (!ExperimentServiceBasicValidation.validateCreateTemplateResponse201Response(response.body)) {
                validateCreateTemplateOutput.errors = ExperimentServiceBasicValidation.validateCreateTemplateResponse201Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 202) {
            if (!ExperimentServiceBasicValidation.validateCreateTemplateResponse202Response(response.body)) {
                validateCreateTemplateOutput.errors = ExperimentServiceBasicValidation.validateCreateTemplateResponse202Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateCreateTemplateOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    ExperimentServiceRequestValidation.validateCreateTemplateOutput = validateCreateTemplateOutput;
    /**
     * This function validates the inputs to getTemplate()
     */
    function validateGetTemplateInput(parameters) {
        if (parameters) {
            if (!ExperimentServiceBasicValidation.validateTemplateIdRequest(parameters["template_id"])) {
                validateGetTemplateInput.errors = ExperimentServiceBasicValidation.validateTemplateIdRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        return true;
    }
    ExperimentServiceRequestValidation.validateGetTemplateInput = validateGetTemplateInput;
    /**
     * This function validates the outputs of getTemplate()
     */
    function validateGetTemplateOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!ExperimentServiceBasicValidation.validateGetTemplateResponse200Response(response.body)) {
                validateGetTemplateOutput.errors = ExperimentServiceBasicValidation.validateGetTemplateResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateGetTemplateOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    ExperimentServiceRequestValidation.validateGetTemplateOutput = validateGetTemplateOutput;
    /**
     * This function validates the inputs to updateTemplate()
     */
    function validateUpdateTemplateInput(parameters, body) {
        if (parameters) {
            if (!ExperimentServiceBasicValidation.validateTemplateIdRequest(parameters["template_id"])) {
                validateUpdateTemplateInput.errors = ExperimentServiceBasicValidation.validateTemplateIdRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        if (!ExperimentServiceBasicValidation.validateUpdateTemplateBodyRequest(body)) {
            validateUpdateTemplateInput.errors = ExperimentServiceBasicValidation.validateUpdateTemplateBodyRequest.errors;
            return false;
        }
        return true;
    }
    ExperimentServiceRequestValidation.validateUpdateTemplateInput = validateUpdateTemplateInput;
    /**
     * This function validates the outputs of updateTemplate()
     */
    function validateUpdateTemplateOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!ExperimentServiceBasicValidation.validateUpdateTemplateResponse200Response(response.body)) {
                validateUpdateTemplateOutput.errors = ExperimentServiceBasicValidation.validateUpdateTemplateResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 202) {
            if (!ExperimentServiceBasicValidation.validateUpdateTemplateResponse202Response(response.body)) {
                validateUpdateTemplateOutput.errors = ExperimentServiceBasicValidation.validateUpdateTemplateResponse202Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateUpdateTemplateOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    ExperimentServiceRequestValidation.validateUpdateTemplateOutput = validateUpdateTemplateOutput;
    /**
     * This function validates the inputs to deleteTemplate()
     */
    function validateDeleteTemplateInput(parameters) {
        if (parameters) {
            if (!ExperimentServiceBasicValidation.validateTemplateIdRequest(parameters["template_id"])) {
                validateDeleteTemplateInput.errors = ExperimentServiceBasicValidation.validateTemplateIdRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        return true;
    }
    ExperimentServiceRequestValidation.validateDeleteTemplateInput = validateDeleteTemplateInput;
    /**
     * This function validates the outputs of deleteTemplate()
     */
    function validateDeleteTemplateOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 204) {
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateDeleteTemplateOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    ExperimentServiceRequestValidation.validateDeleteTemplateOutput = validateDeleteTemplateOutput;
})(ExperimentServiceRequestValidation || (ExperimentServiceRequestValidation = {}));
/**
 * Namespace containing the request validation functions for the Federation Service.
 */
export var FederationServiceRequestValidation;
(function (FederationServiceRequestValidation) {
    /**
     * This function validates the inputs to listInstitutions()
     */
    function validateListInstitutionsInput() {
        return true;
    }
    FederationServiceRequestValidation.validateListInstitutionsInput = validateListInstitutionsInput;
    /**
     * This function validates the outputs of listInstitutions()
     */
    function validateListInstitutionsOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!FederationServiceBasicValidation.validateListInstitutionsResponse200Response(response.body)) {
                validateListInstitutionsOutput.errors = FederationServiceBasicValidation.validateListInstitutionsResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateListInstitutionsOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    FederationServiceRequestValidation.validateListInstitutionsOutput = validateListInstitutionsOutput;
    /**
     * This function validates the inputs to createInstitution()
     */
    function validateCreateInstitutionInput(body) {
        if (!FederationServiceBasicValidation.validateCreateInstitutionBodyRequest(body)) {
            validateCreateInstitutionInput.errors = FederationServiceBasicValidation.validateCreateInstitutionBodyRequest.errors;
            return false;
        }
        return true;
    }
    FederationServiceRequestValidation.validateCreateInstitutionInput = validateCreateInstitutionInput;
    /**
     * This function validates the outputs of createInstitution()
     */
    function validateCreateInstitutionOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 201) {
            if (!FederationServiceBasicValidation.validateCreateInstitutionResponse201Response(response.body)) {
                validateCreateInstitutionOutput.errors = FederationServiceBasicValidation.validateCreateInstitutionResponse201Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateCreateInstitutionOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    FederationServiceRequestValidation.validateCreateInstitutionOutput = validateCreateInstitutionOutput;
    /**
     * This function validates the inputs to getInstitution()
     */
    function validateGetInstitutionInput(parameters) {
        if (parameters) {
            if (!FederationServiceBasicValidation.validateInstitutionIdRequest(parameters["institution_id"])) {
                validateGetInstitutionInput.errors = FederationServiceBasicValidation.validateInstitutionIdRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        return true;
    }
    FederationServiceRequestValidation.validateGetInstitutionInput = validateGetInstitutionInput;
    /**
     * This function validates the outputs of getInstitution()
     */
    function validateGetInstitutionOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!FederationServiceBasicValidation.validateGetInstitutionResponse200Response(response.body)) {
                validateGetInstitutionOutput.errors = FederationServiceBasicValidation.validateGetInstitutionResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateGetInstitutionOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    FederationServiceRequestValidation.validateGetInstitutionOutput = validateGetInstitutionOutput;
    /**
     * This function validates the inputs to updateInstitution()
     */
    function validateUpdateInstitutionInput(parameters, body) {
        if (parameters) {
            if (!FederationServiceBasicValidation.validateInstitutionIdRequest(parameters["institution_id"])) {
                validateUpdateInstitutionInput.errors = FederationServiceBasicValidation.validateInstitutionIdRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        if (body === undefined) {
            return true;
        }
        if (!FederationServiceBasicValidation.validateUpdateInstitutionBodyRequest(body)) {
            validateUpdateInstitutionInput.errors = FederationServiceBasicValidation.validateUpdateInstitutionBodyRequest.errors;
            return false;
        }
        return true;
    }
    FederationServiceRequestValidation.validateUpdateInstitutionInput = validateUpdateInstitutionInput;
    /**
     * This function validates the outputs of updateInstitution()
     */
    function validateUpdateInstitutionOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!FederationServiceBasicValidation.validateUpdateInstitutionResponse200Response(response.body)) {
                validateUpdateInstitutionOutput.errors = FederationServiceBasicValidation.validateUpdateInstitutionResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateUpdateInstitutionOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    FederationServiceRequestValidation.validateUpdateInstitutionOutput = validateUpdateInstitutionOutput;
    /**
     * This function validates the inputs to deleteInstitution()
     */
    function validateDeleteInstitutionInput(parameters) {
        if (parameters) {
            if (!FederationServiceBasicValidation.validateInstitutionIdRequest(parameters["institution_id"])) {
                validateDeleteInstitutionInput.errors = FederationServiceBasicValidation.validateInstitutionIdRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        return true;
    }
    FederationServiceRequestValidation.validateDeleteInstitutionInput = validateDeleteInstitutionInput;
    /**
     * This function validates the outputs of deleteInstitution()
     */
    function validateDeleteInstitutionOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 204) {
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            return true;
        }
        validateDeleteInstitutionOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    FederationServiceRequestValidation.validateDeleteInstitutionOutput = validateDeleteInstitutionOutput;
})(FederationServiceRequestValidation || (FederationServiceRequestValidation = {}));
/**
 * Namespace containing the request validation functions for the Booking Service.
 */
export var BookingServiceRequestValidation;
(function (BookingServiceRequestValidation) {
    /**
     * This function validates the inputs to schedule()
     */
    function validateScheduleInput(body) {
        if (body === undefined) {
            return true;
        }
        if (!BookingServiceBasicValidation.validateScheduleBodyRequest(body)) {
            validateScheduleInput.errors = BookingServiceBasicValidation.validateScheduleBodyRequest.errors;
            return false;
        }
        return true;
    }
    BookingServiceRequestValidation.validateScheduleInput = validateScheduleInput;
    /**
     * This function validates the outputs of schedule()
     */
    function validateScheduleOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!BookingServiceBasicValidation.validateScheduleResponse200Response(response.body)) {
                validateScheduleOutput.errors = BookingServiceBasicValidation.validateScheduleResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            if (!BookingServiceBasicValidation.validateScheduleResponse404Response(response.body)) {
                validateScheduleOutput.errors = BookingServiceBasicValidation.validateScheduleResponse404Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 422) {
            if (!BookingServiceBasicValidation.validateScheduleResponse422Response(response.body)) {
                validateScheduleOutput.errors = BookingServiceBasicValidation.validateScheduleResponse422Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 500) {
            if (!BookingServiceBasicValidation.validateScheduleResponse500Response(response.body)) {
                validateScheduleOutput.errors = BookingServiceBasicValidation.validateScheduleResponse500Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 503) {
            return true;
        }
        validateScheduleOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    BookingServiceRequestValidation.validateScheduleOutput = validateScheduleOutput;
    /**
     * This function validates the inputs to newBooking()
     */
    function validateNewBookingInput(body) {
        if (!BookingServiceBasicValidation.validateNewBookingBodyRequest(body)) {
            validateNewBookingInput.errors = BookingServiceBasicValidation.validateNewBookingBodyRequest.errors;
            return false;
        }
        return true;
    }
    BookingServiceRequestValidation.validateNewBookingInput = validateNewBookingInput;
    /**
     * This function validates the outputs of newBooking()
     */
    function validateNewBookingOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!BookingServiceBasicValidation.validateNewBookingResponse200Response(response.body)) {
                validateNewBookingOutput.errors = BookingServiceBasicValidation.validateNewBookingResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 500) {
            if (!BookingServiceBasicValidation.validateNewBookingResponse500Response(response.body)) {
                validateNewBookingOutput.errors = BookingServiceBasicValidation.validateNewBookingResponse500Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 503) {
            return true;
        }
        validateNewBookingOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    BookingServiceRequestValidation.validateNewBookingOutput = validateNewBookingOutput;
    /**
     * This function validates the inputs to updateBooking()
     */
    function validateUpdateBookingInput(parameters, body) {
        if (parameters) {
            if (!BookingServiceBasicValidation.validateIDRequest(parameters["ID"])) {
                validateUpdateBookingInput.errors = BookingServiceBasicValidation.validateIDRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        if (!BookingServiceBasicValidation.validateUpdateBookingBodyRequest(body)) {
            validateUpdateBookingInput.errors = BookingServiceBasicValidation.validateUpdateBookingBodyRequest.errors;
            return false;
        }
        return true;
    }
    BookingServiceRequestValidation.validateUpdateBookingInput = validateUpdateBookingInput;
    /**
     * This function validates the outputs of updateBooking()
     */
    function validateUpdateBookingOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!BookingServiceBasicValidation.validateUpdateBookingResponse200Response(response.body)) {
                validateUpdateBookingOutput.errors = BookingServiceBasicValidation.validateUpdateBookingResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 400) {
            if (!BookingServiceBasicValidation.validateUpdateBookingResponse400Response(response.body)) {
                validateUpdateBookingOutput.errors = BookingServiceBasicValidation.validateUpdateBookingResponse400Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 423) {
            return true;
        }
        if (response.status === 500) {
            if (!BookingServiceBasicValidation.validateUpdateBookingResponse500Response(response.body)) {
                validateUpdateBookingOutput.errors = BookingServiceBasicValidation.validateUpdateBookingResponse500Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 503) {
            return true;
        }
        validateUpdateBookingOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    BookingServiceRequestValidation.validateUpdateBookingOutput = validateUpdateBookingOutput;
    /**
     * This function validates the inputs to deleteBooking()
     */
    function validateDeleteBookingInput(parameters) {
        if (parameters) {
            if (!BookingServiceBasicValidation.validateIDRequest(parameters["ID"])) {
                validateDeleteBookingInput.errors = BookingServiceBasicValidation.validateIDRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        return true;
    }
    BookingServiceRequestValidation.validateDeleteBookingInput = validateDeleteBookingInput;
    /**
     * This function validates the outputs of deleteBooking()
     */
    function validateDeleteBookingOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 423) {
            return true;
        }
        if (response.status === 500) {
            if (!BookingServiceBasicValidation.validateDeleteBookingResponse500Response(response.body)) {
                validateDeleteBookingOutput.errors = BookingServiceBasicValidation.validateDeleteBookingResponse500Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 503) {
            return true;
        }
        validateDeleteBookingOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    BookingServiceRequestValidation.validateDeleteBookingOutput = validateDeleteBookingOutput;
    /**
     * This function validates the inputs to getBooking()
     */
    function validateGetBookingInput(parameters) {
        if (parameters) {
            if (!BookingServiceBasicValidation.validateIDRequest(parameters["ID"])) {
                validateGetBookingInput.errors = BookingServiceBasicValidation.validateIDRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        return true;
    }
    BookingServiceRequestValidation.validateGetBookingInput = validateGetBookingInput;
    /**
     * This function validates the outputs of getBooking()
     */
    function validateGetBookingOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!BookingServiceBasicValidation.validateGetBookingResponse200Response(response.body)) {
                validateGetBookingOutput.errors = BookingServiceBasicValidation.validateGetBookingResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            if (!BookingServiceBasicValidation.validateGetBookingResponse500Response(response.body)) {
                validateGetBookingOutput.errors = BookingServiceBasicValidation.validateGetBookingResponse500Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 503) {
            return true;
        }
        validateGetBookingOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    BookingServiceRequestValidation.validateGetBookingOutput = validateGetBookingOutput;
    /**
     * This function validates the inputs to destroyBooking()
     */
    function validateDestroyBookingInput(parameters) {
        if (parameters) {
            if (!BookingServiceBasicValidation.validateIDRequest(parameters["ID"])) {
                validateDestroyBookingInput.errors = BookingServiceBasicValidation.validateIDRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        return true;
    }
    BookingServiceRequestValidation.validateDestroyBookingInput = validateDestroyBookingInput;
    /**
     * This function validates the outputs of destroyBooking()
     */
    function validateDestroyBookingOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 423) {
            return true;
        }
        if (response.status === 500) {
            if (!BookingServiceBasicValidation.validateDestroyBookingResponse500Response(response.body)) {
                validateDestroyBookingOutput.errors = BookingServiceBasicValidation.validateDestroyBookingResponse500Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 503) {
            return true;
        }
        validateDestroyBookingOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    BookingServiceRequestValidation.validateDestroyBookingOutput = validateDestroyBookingOutput;
    /**
     * This function validates the inputs to lockBooking()
     */
    function validateLockBookingInput(parameters) {
        if (parameters) {
            if (!BookingServiceBasicValidation.validateIDRequest(parameters["ID"])) {
                validateLockBookingInput.errors = BookingServiceBasicValidation.validateIDRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        return true;
    }
    BookingServiceRequestValidation.validateLockBookingInput = validateLockBookingInput;
    /**
     * This function validates the outputs of lockBooking()
     */
    function validateLockBookingOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            if (!BookingServiceBasicValidation.validateLockBookingResponse200Response(response.body)) {
                validateLockBookingOutput.errors = BookingServiceBasicValidation.validateLockBookingResponse200Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 412) {
            return true;
        }
        if (response.status === 500) {
            if (!BookingServiceBasicValidation.validateLockBookingResponse500Response(response.body)) {
                validateLockBookingOutput.errors = BookingServiceBasicValidation.validateLockBookingResponse500Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 503) {
            return true;
        }
        validateLockBookingOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    BookingServiceRequestValidation.validateLockBookingOutput = validateLockBookingOutput;
    /**
     * This function validates the inputs to unlockBooking()
     */
    function validateUnlockBookingInput(parameters) {
        if (parameters) {
            if (!BookingServiceBasicValidation.validateIDRequest(parameters["ID"])) {
                validateUnlockBookingInput.errors = BookingServiceBasicValidation.validateIDRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        return true;
    }
    BookingServiceRequestValidation.validateUnlockBookingInput = validateUnlockBookingInput;
    /**
     * This function validates the outputs of unlockBooking()
     */
    function validateUnlockBookingOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            return true;
        }
        if (response.status === 401) {
            return true;
        }
        if (response.status === 403) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 412) {
            return true;
        }
        if (response.status === 500) {
            if (!BookingServiceBasicValidation.validateUnlockBookingResponse500Response(response.body)) {
                validateUnlockBookingOutput.errors = BookingServiceBasicValidation.validateUnlockBookingResponse500Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 503) {
            return true;
        }
        validateUnlockBookingOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    BookingServiceRequestValidation.validateUnlockBookingOutput = validateUnlockBookingOutput;
    /**
     * This function validates the inputs to bookingCallback()
     */
    function validateBookingCallbackInput(parameters) {
        if (parameters) {
            if (!BookingServiceBasicValidation.validateIDRequest(parameters["ID"])) {
                validateBookingCallbackInput.errors = BookingServiceBasicValidation.validateIDRequest.errors;
                return false;
            }
        }
        else {
            return false;
        }
        return true;
    }
    BookingServiceRequestValidation.validateBookingCallbackInput = validateBookingCallbackInput;
    /**
     * This function validates the outputs of bookingCallback()
     */
    function validateBookingCallbackOutput(response) {
        if (response.status < 100 || response.status >= 600)
            return false;
        if (response.status === 200) {
            return true;
        }
        if (response.status === 404) {
            return true;
        }
        if (response.status === 500) {
            if (!BookingServiceBasicValidation.validateBookingCallbackResponse500Response(response.body)) {
                validateBookingCallbackOutput.errors = BookingServiceBasicValidation.validateBookingCallbackResponse500Response.errors;
                return false;
            }
            return true;
        }
        if (response.status === 503) {
            return true;
        }
        validateBookingCallbackOutput.errors = `Response status ${response.status} is unexpected`;
        return false;
    }
    BookingServiceRequestValidation.validateBookingCallbackOutput = validateBookingCallbackOutput;
})(BookingServiceRequestValidation || (BookingServiceRequestValidation = {}));
//# sourceMappingURL=requestValidation.js.map