/**
 * @internal
 */
export interface RequestInfo {
    method?: "GET" | "POST" | "PUT" | "DELETE" | "TRACE" | "OPTIONS" | "PATCH" | "HEAD";
    body?: string;
    headers?: [string, string][];
}
/**
 * @internal
 */
export type FetchFunction = (url: string, info?: RequestInfo) => Promise<ResponseData> | ResponseData;
export interface ResponseData {
    status: number;
    headers?: {
        [key: string]: string | undefined;
    };
    body?: unknown;
}
export interface SuccessResponse extends ResponseData {
    success?: true;
}
export interface ErrorResponse extends ResponseData {
    success?: false;
}
/**
 * @internal
 */
export declare function isSuccessResponse(response: ResponseData): response is SuccessResponse;
/**
 * @internal
 */
export declare function isErrorResponse(response: ResponseData): response is ErrorResponse;
/**
 * This type allows to pick the required properties of another type.
 */
export type Require<Type, Key extends keyof Type> = Partial<Type> & {
    [Property in Key]-?: Type[Property];
};
export type SizedTuple<T, MIN extends number | undefined = undefined, MAX extends number | undefined = undefined> = MIN extends number ? MAX extends number ? _SizedTuple<T, NumericRangeTuple<MIN, MAX>> : TupleObject<T, NumericRangeTuple<0, MIN>> & T[] : MAX extends number ? _SizedTuple<T, NumericRangeTuple<0, MAX>, true> : T[];
type _SizedTuple<T, ARR extends number[], Z extends boolean = false> = ARR extends [infer HEAD extends number, ...infer TAIL extends number[]] ? Tuple<T, HEAD, Z> | _SizedTuple<T, TAIL, Z> : never;
type Tuple<T, N extends number, Z extends boolean = false> = _Tuple<T, NumericRangeTuple<Z extends true ? 0 : 1, N>>;
type _Tuple<T, N extends number[]> = N extends [
    infer HEAD,
    ...infer TAIL extends number[]
] ? HEAD extends 0 ? [] | _Tuple<T, TAIL> : [T, ..._Tuple<T, TAIL>] : [];
type TupleObject<T, N extends number[]> = N extends [
    infer HEAD extends number,
    ...infer TAIL extends number[]
] ? TAIL extends [] ? {} : {
    [P in HEAD]: T;
} & TupleObject<T, TAIL> : {};
export type NumericRange<START extends number, END extends number, ARR extends unknown[] = [], ACC extends number = never> = ARR['length'] extends END ? ACC | START | END : NumericRange<START, END, [
    ...ARR,
    1
], ARR[START] extends undefined ? ACC : ACC | ARR['length']>;
type NumericRangeTuple<START extends number, END extends number, ARR extends unknown[] = [], ACC extends number[] = []> = ARR['length'] extends END ? [START, ...ACC, END] : NumericRangeTuple<START, END, [
    ...ARR,
    1
], ARR[START] extends undefined ? ACC : [...ACC, ARR['length']]>;
/**
 * Namespace containing the types for the Authentication Service.
 */
export declare namespace AuthenticationServiceTypes {
    type Credentials<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * Username of the user.
         */
        username: string;
        /**
         * Password of the user.
         */
        password: string;
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * Username of the user.
         */
        username: string;
        /**
         * Password of the user.
         */
        password: string;
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * Username of the user.
         */
        username: string;
        /**
         * Password of the user.
         */
        password: string;
        [k: string]: unknown;
    } : never;
    /**
* Authentication method.
*/
    type AuthMethod<T extends "request" | "response" | "all" = "all"> = T extends "all" ? "tui" | "local" : T extends "request" ? "tui" | "local" : T extends "response" ? "tui" | "local" : never;
    type User<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        url?: string;
        id?: string;
        username?: string;
        password?: string;
        admin?: boolean;
        [k: string]: unknown;
    } : T extends "request" ? {
        username?: string;
        password?: string;
        admin?: boolean;
        [k: string]: unknown;
    } : T extends "response" ? {
        url?: string;
        id?: string;
        username?: string;
        admin?: boolean;
        [k: string]: unknown;
    } : never;
    function isUser<T extends "request" | "response" | "all" = "all">(obj: unknown, type?: "request" | "response" | "all" | T): obj is User<T>;
}
/**
 * Namespace containing the types for the Device Service.
 */
export declare namespace DeviceServiceTypes {
    type UserReference<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * URL of the user
         */
        url: string;
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * URL of the user
         */
        url: string;
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * URL of the user
         */
        url: string;
        [k: string]: unknown;
    } : never;
    type DeviceOverview<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * URL of the device
         */
        url: string;
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference[];
        /**
         * List of users who own the device
         */
        owner?: UserReference[];
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"request">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"request">[];
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * URL of the device
         */
        url: string;
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"response">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"response">[];
        [k: string]: unknown;
    } : never;
    type ServiceDescription<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        serviceType?: string;
        serviceId?: string;
        serviceDirection?: "consumer" | "producer" | "prosumer";
        [k: string]: unknown;
    } : T extends "request" ? {
        serviceType?: string;
        serviceId?: string;
        serviceDirection?: "consumer" | "producer" | "prosumer";
        [k: string]: unknown;
    } : T extends "response" ? {
        serviceType?: string;
        serviceId?: string;
        serviceDirection?: "consumer" | "producer" | "prosumer";
        [k: string]: unknown;
    } : never;
    type InstantiableCloudDevice<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * URL of the device
         */
        url: string;
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference[];
        /**
         * List of users who own the device
         */
        owner?: UserReference[];
        [k: string]: unknown;
    } & {
        type?: "cloud instantiable";
        instantiateUrl?: string;
        services?: ServiceDescription[];
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"request">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"request">[];
        [k: string]: unknown;
    } & {
        type?: "cloud instantiable";
        instantiateUrl?: string;
        services?: ServiceDescription<"request">[];
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * URL of the device
         */
        url: string;
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"response">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"response">[];
        [k: string]: unknown;
    } & {
        type?: "cloud instantiable";
        instantiateUrl?: string;
        services?: ServiceDescription<"response">[];
        [k: string]: unknown;
    } : never;
    type TimeSlot<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        start?: string;
        end?: string;
        [k: string]: unknown;
    } : T extends "request" ? {
        start?: string;
        end?: string;
        [k: string]: unknown;
    } : T extends "response" ? {
        start?: string;
        end?: string;
        [k: string]: unknown;
    } : never;
    /**
* A list of time slots that the maintainer of the device announced it is available
*
*/
    type Availability<T extends "request" | "response" | "all" = "all"> = T extends "all" ? TimeSlot[] : T extends "request" ? TimeSlot<"request">[] : T extends "response" ? TimeSlot<"response">[] : never;
    type ConcreteDevice<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * URL of the device
         */
        url: string;
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference[];
        /**
         * List of users who own the device
         */
        owner?: UserReference[];
        [k: string]: unknown;
    } & {
        type?: "device";
        /**
         * If true, the device is connected to the service and can be used.
         *
         */
        connected?: boolean;
        /**
         * A list of time slots that the maintainer of the device announced it is available
         *
         */
        announcedAvailability?: TimeSlot[];
        experiment?: string;
        services?: ServiceDescription[];
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"request">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"request">[];
        [k: string]: unknown;
    } & {
        type?: "device";
        experiment?: string;
        services?: ServiceDescription<"request">[];
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * URL of the device
         */
        url: string;
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"response">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"response">[];
        [k: string]: unknown;
    } & {
        type?: "device";
        /**
         * If true, the device is connected to the service and can be used.
         *
         */
        connected?: boolean;
        /**
         * A list of time slots that the maintainer of the device announced it is available
         *
         */
        announcedAvailability?: TimeSlot<"response">[];
        experiment?: string;
        services?: ServiceDescription<"response">[];
        [k: string]: unknown;
    } : never;
    type InstantiableBrowserDevice<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * URL of the device
         */
        url: string;
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference[];
        /**
         * List of users who own the device
         */
        owner?: UserReference[];
        [k: string]: unknown;
    } & {
        type?: "edge instantiable";
        codeUrl?: string;
        services?: ServiceDescription[];
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"request">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"request">[];
        [k: string]: unknown;
    } & {
        type?: "edge instantiable";
        codeUrl?: string;
        services?: ServiceDescription<"request">[];
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * URL of the device
         */
        url: string;
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"response">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"response">[];
        [k: string]: unknown;
    } & {
        type?: "edge instantiable";
        codeUrl?: string;
        services?: ServiceDescription<"response">[];
        [k: string]: unknown;
    } : never;
    type DeviceReference<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * URL of the device
         */
        url: string;
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * URL of the device
         */
        url: string;
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * URL of the device
         */
        url: string;
        [k: string]: unknown;
    } : never;
    type DeviceGroup<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * URL of the device
         */
        url: string;
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference[];
        /**
         * List of users who own the device
         */
        owner?: UserReference[];
        [k: string]: unknown;
    } & {
        type?: "group";
        devices: DeviceReference[];
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"request">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"request">[];
        [k: string]: unknown;
    } & {
        type?: "group";
        devices: DeviceReference<"request">[];
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * URL of the device
         */
        url: string;
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"response">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"response">[];
        [k: string]: unknown;
    } & {
        type?: "group";
        devices: DeviceReference<"response">[];
        [k: string]: unknown;
    } : never;
    type Device<T extends "request" | "response" | "all" = "all"> = T extends "all" ? ({
        /**
         * URL of the device
         */
        url: string;
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference[];
        /**
         * List of users who own the device
         */
        owner?: UserReference[];
        [k: string]: unknown;
    } & {
        type?: "cloud instantiable";
        instantiateUrl?: string;
        services?: ServiceDescription[];
        [k: string]: unknown;
    }) | ({
        /**
         * URL of the device
         */
        url: string;
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference[];
        /**
         * List of users who own the device
         */
        owner?: UserReference[];
        [k: string]: unknown;
    } & {
        type?: "device";
        /**
         * If true, the device is connected to the service and can be used.
         *
         */
        connected?: boolean;
        /**
         * A list of time slots that the maintainer of the device announced it is available
         *
         */
        announcedAvailability?: TimeSlot[];
        experiment?: string;
        services?: ServiceDescription[];
        [k: string]: unknown;
    }) | ({
        /**
         * URL of the device
         */
        url: string;
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference[];
        /**
         * List of users who own the device
         */
        owner?: UserReference[];
        [k: string]: unknown;
    } & {
        type?: "edge instantiable";
        codeUrl?: string;
        services?: ServiceDescription[];
        [k: string]: unknown;
    }) | ({
        /**
         * URL of the device
         */
        url: string;
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference[];
        /**
         * List of users who own the device
         */
        owner?: UserReference[];
        [k: string]: unknown;
    } & {
        type?: "group";
        devices: DeviceReference[];
        [k: string]: unknown;
    }) : T extends "request" ? ({
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"request">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"request">[];
        [k: string]: unknown;
    } & {
        type?: "cloud instantiable";
        instantiateUrl?: string;
        services?: ServiceDescription<"request">[];
        [k: string]: unknown;
    }) | ({
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"request">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"request">[];
        [k: string]: unknown;
    } & {
        type?: "device";
        experiment?: string;
        services?: ServiceDescription<"request">[];
        [k: string]: unknown;
    }) | ({
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"request">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"request">[];
        [k: string]: unknown;
    } & {
        type?: "edge instantiable";
        codeUrl?: string;
        services?: ServiceDescription<"request">[];
        [k: string]: unknown;
    }) | ({
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"request">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"request">[];
        [k: string]: unknown;
    } & {
        type?: "group";
        devices: DeviceReference<"request">[];
        [k: string]: unknown;
    }) : T extends "response" ? ({
        /**
         * URL of the device
         */
        url: string;
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"response">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"response">[];
        [k: string]: unknown;
    } & {
        type?: "cloud instantiable";
        instantiateUrl?: string;
        services?: ServiceDescription<"response">[];
        [k: string]: unknown;
    }) | ({
        /**
         * URL of the device
         */
        url: string;
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"response">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"response">[];
        [k: string]: unknown;
    } & {
        type?: "device";
        /**
         * If true, the device is connected to the service and can be used.
         *
         */
        connected?: boolean;
        /**
         * A list of time slots that the maintainer of the device announced it is available
         *
         */
        announcedAvailability?: TimeSlot<"response">[];
        experiment?: string;
        services?: ServiceDescription<"response">[];
        [k: string]: unknown;
    }) | ({
        /**
         * URL of the device
         */
        url: string;
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"response">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"response">[];
        [k: string]: unknown;
    } & {
        type?: "edge instantiable";
        codeUrl?: string;
        services?: ServiceDescription<"response">[];
        [k: string]: unknown;
    }) | ({
        /**
         * URL of the device
         */
        url: string;
        /**
         * Name of the device
         */
        name: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"response">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"response">[];
        [k: string]: unknown;
    } & {
        type?: "group";
        devices: DeviceReference<"response">[];
        [k: string]: unknown;
    }) : never;
    type Callback<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        callbackType: string;
        [k: string]: unknown;
    } : T extends "request" ? {
        callbackType: string;
        [k: string]: unknown;
    } : T extends "response" ? {
        callbackType: string;
        [k: string]: unknown;
    } : never;
    type EventCallback<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        callbackType: string;
        [k: string]: unknown;
    } & {
        callbackType: "event";
        eventType: string;
        [k: string]: unknown;
    } : T extends "request" ? {
        callbackType: string;
        [k: string]: unknown;
    } & {
        callbackType: "event";
        eventType: string;
        [k: string]: unknown;
    } : T extends "response" ? {
        callbackType: string;
        [k: string]: unknown;
    } & {
        callbackType: "event";
        eventType: string;
        [k: string]: unknown;
    } : never;
    type DeviceChangedEventCallback<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        callbackType: string;
        [k: string]: unknown;
    } & {
        callbackType: "event";
        eventType: string;
        [k: string]: unknown;
    } & {
        eventType: "device-changed";
        device: ({
            /**
             * URL of the device
             */
            url: string;
            /**
             * Name of the device
             */
            name: string;
            /**
             * Extended description of the device, features, etc.
             */
            description?: string;
            /**
             * Type of the device
             */
            type: "device" | "group" | "edge instantiable" | "cloud instantiable";
            /**
             * If true, the device may be seen and used by every user.
             */
            isPublic: boolean;
            /**
             * List of users who can view the device
             */
            viewer?: UserReference[];
            /**
             * List of users who own the device
             */
            owner?: UserReference[];
            [k: string]: unknown;
        } & {
            type?: "cloud instantiable";
            instantiateUrl?: string;
            services?: ServiceDescription[];
            [k: string]: unknown;
        }) | ({
            /**
             * URL of the device
             */
            url: string;
            /**
             * Name of the device
             */
            name: string;
            /**
             * Extended description of the device, features, etc.
             */
            description?: string;
            /**
             * Type of the device
             */
            type: "device" | "group" | "edge instantiable" | "cloud instantiable";
            /**
             * If true, the device may be seen and used by every user.
             */
            isPublic: boolean;
            /**
             * List of users who can view the device
             */
            viewer?: UserReference[];
            /**
             * List of users who own the device
             */
            owner?: UserReference[];
            [k: string]: unknown;
        } & {
            type?: "device";
            /**
             * If true, the device is connected to the service and can be used.
             *
             */
            connected?: boolean;
            /**
             * A list of time slots that the maintainer of the device announced it is available
             *
             */
            announcedAvailability?: TimeSlot[];
            experiment?: string;
            services?: ServiceDescription[];
            [k: string]: unknown;
        }) | ({
            /**
             * URL of the device
             */
            url: string;
            /**
             * Name of the device
             */
            name: string;
            /**
             * Extended description of the device, features, etc.
             */
            description?: string;
            /**
             * Type of the device
             */
            type: "device" | "group" | "edge instantiable" | "cloud instantiable";
            /**
             * If true, the device may be seen and used by every user.
             */
            isPublic: boolean;
            /**
             * List of users who can view the device
             */
            viewer?: UserReference[];
            /**
             * List of users who own the device
             */
            owner?: UserReference[];
            [k: string]: unknown;
        } & {
            type?: "edge instantiable";
            codeUrl?: string;
            services?: ServiceDescription[];
            [k: string]: unknown;
        }) | ({
            /**
             * URL of the device
             */
            url: string;
            /**
             * Name of the device
             */
            name: string;
            /**
             * Extended description of the device, features, etc.
             */
            description?: string;
            /**
             * Type of the device
             */
            type: "device" | "group" | "edge instantiable" | "cloud instantiable";
            /**
             * If true, the device may be seen and used by every user.
             */
            isPublic: boolean;
            /**
             * List of users who can view the device
             */
            viewer?: UserReference[];
            /**
             * List of users who own the device
             */
            owner?: UserReference[];
            [k: string]: unknown;
        } & {
            type?: "group";
            devices: DeviceReference[];
            [k: string]: unknown;
        });
        [k: string]: unknown;
    } : T extends "request" ? {
        callbackType: string;
        [k: string]: unknown;
    } & {
        callbackType: "event";
        eventType: string;
        [k: string]: unknown;
    } & {
        eventType: "device-changed";
        device: ({
            /**
             * Name of the device
             */
            name: string;
            /**
             * Extended description of the device, features, etc.
             */
            description?: string;
            /**
             * Type of the device
             */
            type: "device" | "group" | "edge instantiable" | "cloud instantiable";
            /**
             * If true, the device may be seen and used by every user.
             */
            isPublic: boolean;
            /**
             * List of users who can view the device
             */
            viewer?: UserReference<"request">[];
            /**
             * List of users who own the device
             */
            owner?: UserReference<"request">[];
            [k: string]: unknown;
        } & {
            type?: "cloud instantiable";
            instantiateUrl?: string;
            services?: ServiceDescription<"request">[];
            [k: string]: unknown;
        }) | ({
            /**
             * Name of the device
             */
            name: string;
            /**
             * Extended description of the device, features, etc.
             */
            description?: string;
            /**
             * Type of the device
             */
            type: "device" | "group" | "edge instantiable" | "cloud instantiable";
            /**
             * If true, the device may be seen and used by every user.
             */
            isPublic: boolean;
            /**
             * List of users who can view the device
             */
            viewer?: UserReference<"request">[];
            /**
             * List of users who own the device
             */
            owner?: UserReference<"request">[];
            [k: string]: unknown;
        } & {
            type?: "device";
            experiment?: string;
            services?: ServiceDescription<"request">[];
            [k: string]: unknown;
        }) | ({
            /**
             * Name of the device
             */
            name: string;
            /**
             * Extended description of the device, features, etc.
             */
            description?: string;
            /**
             * Type of the device
             */
            type: "device" | "group" | "edge instantiable" | "cloud instantiable";
            /**
             * If true, the device may be seen and used by every user.
             */
            isPublic: boolean;
            /**
             * List of users who can view the device
             */
            viewer?: UserReference<"request">[];
            /**
             * List of users who own the device
             */
            owner?: UserReference<"request">[];
            [k: string]: unknown;
        } & {
            type?: "edge instantiable";
            codeUrl?: string;
            services?: ServiceDescription<"request">[];
            [k: string]: unknown;
        }) | ({
            /**
             * Name of the device
             */
            name: string;
            /**
             * Extended description of the device, features, etc.
             */
            description?: string;
            /**
             * Type of the device
             */
            type: "device" | "group" | "edge instantiable" | "cloud instantiable";
            /**
             * If true, the device may be seen and used by every user.
             */
            isPublic: boolean;
            /**
             * List of users who can view the device
             */
            viewer?: UserReference<"request">[];
            /**
             * List of users who own the device
             */
            owner?: UserReference<"request">[];
            [k: string]: unknown;
        } & {
            type?: "group";
            devices: DeviceReference<"request">[];
            [k: string]: unknown;
        });
        [k: string]: unknown;
    } : T extends "response" ? {
        callbackType: string;
        [k: string]: unknown;
    } & {
        callbackType: "event";
        eventType: string;
        [k: string]: unknown;
    } & {
        eventType: "device-changed";
        device: ({
            /**
             * URL of the device
             */
            url: string;
            /**
             * Name of the device
             */
            name: string;
            /**
             * Extended description of the device, features, etc.
             */
            description?: string;
            /**
             * Type of the device
             */
            type: "device" | "group" | "edge instantiable" | "cloud instantiable";
            /**
             * If true, the device may be seen and used by every user.
             */
            isPublic: boolean;
            /**
             * List of users who can view the device
             */
            viewer?: UserReference<"response">[];
            /**
             * List of users who own the device
             */
            owner?: UserReference<"response">[];
            [k: string]: unknown;
        } & {
            type?: "cloud instantiable";
            instantiateUrl?: string;
            services?: ServiceDescription<"response">[];
            [k: string]: unknown;
        }) | ({
            /**
             * URL of the device
             */
            url: string;
            /**
             * Name of the device
             */
            name: string;
            /**
             * Extended description of the device, features, etc.
             */
            description?: string;
            /**
             * Type of the device
             */
            type: "device" | "group" | "edge instantiable" | "cloud instantiable";
            /**
             * If true, the device may be seen and used by every user.
             */
            isPublic: boolean;
            /**
             * List of users who can view the device
             */
            viewer?: UserReference<"response">[];
            /**
             * List of users who own the device
             */
            owner?: UserReference<"response">[];
            [k: string]: unknown;
        } & {
            type?: "device";
            /**
             * If true, the device is connected to the service and can be used.
             *
             */
            connected?: boolean;
            /**
             * A list of time slots that the maintainer of the device announced it is available
             *
             */
            announcedAvailability?: TimeSlot<"response">[];
            experiment?: string;
            services?: ServiceDescription<"response">[];
            [k: string]: unknown;
        }) | ({
            /**
             * URL of the device
             */
            url: string;
            /**
             * Name of the device
             */
            name: string;
            /**
             * Extended description of the device, features, etc.
             */
            description?: string;
            /**
             * Type of the device
             */
            type: "device" | "group" | "edge instantiable" | "cloud instantiable";
            /**
             * If true, the device may be seen and used by every user.
             */
            isPublic: boolean;
            /**
             * List of users who can view the device
             */
            viewer?: UserReference<"response">[];
            /**
             * List of users who own the device
             */
            owner?: UserReference<"response">[];
            [k: string]: unknown;
        } & {
            type?: "edge instantiable";
            codeUrl?: string;
            services?: ServiceDescription<"response">[];
            [k: string]: unknown;
        }) | ({
            /**
             * URL of the device
             */
            url: string;
            /**
             * Name of the device
             */
            name: string;
            /**
             * Extended description of the device, features, etc.
             */
            description?: string;
            /**
             * Type of the device
             */
            type: "device" | "group" | "edge instantiable" | "cloud instantiable";
            /**
             * If true, the device may be seen and used by every user.
             */
            isPublic: boolean;
            /**
             * List of users who can view the device
             */
            viewer?: UserReference<"response">[];
            /**
             * List of users who own the device
             */
            owner?: UserReference<"response">[];
            [k: string]: unknown;
        } & {
            type?: "group";
            devices: DeviceReference<"response">[];
            [k: string]: unknown;
        });
        [k: string]: unknown;
    } : never;
    type DeviceOverviewUpdate<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference[];
        /**
         * List of users who own the device
         */
        owner?: UserReference[];
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"request">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"request">[];
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"response">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"response">[];
        [k: string]: unknown;
    } : never;
    type InstantiableCloudDeviceUpdate<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference[];
        /**
         * List of users who own the device
         */
        owner?: UserReference[];
        [k: string]: unknown;
    } & {
        type?: "cloud instantiable";
        instantiateUrl?: string;
        services?: ServiceDescription[];
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"request">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"request">[];
        [k: string]: unknown;
    } & {
        type?: "cloud instantiable";
        instantiateUrl?: string;
        services?: ServiceDescription<"request">[];
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"response">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"response">[];
        [k: string]: unknown;
    } & {
        type?: "cloud instantiable";
        instantiateUrl?: string;
        services?: ServiceDescription<"response">[];
        [k: string]: unknown;
    } : never;
    type ConcreteDeviceUpdate<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference[];
        /**
         * List of users who own the device
         */
        owner?: UserReference[];
        [k: string]: unknown;
    } & {
        type?: "device";
        experiment?: string;
        services?: ServiceDescription[];
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"request">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"request">[];
        [k: string]: unknown;
    } & {
        type?: "device";
        experiment?: string;
        services?: ServiceDescription<"request">[];
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"response">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"response">[];
        [k: string]: unknown;
    } & {
        type?: "device";
        experiment?: string;
        services?: ServiceDescription<"response">[];
        [k: string]: unknown;
    } : never;
    type InstantiableBrowserDeviceUpdate<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference[];
        /**
         * List of users who own the device
         */
        owner?: UserReference[];
        [k: string]: unknown;
    } & {
        type?: "edge instantiable";
        codeUrl?: string;
        services?: ServiceDescription[];
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"request">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"request">[];
        [k: string]: unknown;
    } & {
        type?: "edge instantiable";
        codeUrl?: string;
        services?: ServiceDescription<"request">[];
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"response">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"response">[];
        [k: string]: unknown;
    } & {
        type?: "edge instantiable";
        codeUrl?: string;
        services?: ServiceDescription<"response">[];
        [k: string]: unknown;
    } : never;
    type DeviceGroupUpdate<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference[];
        /**
         * List of users who own the device
         */
        owner?: UserReference[];
        [k: string]: unknown;
    } & {
        type?: "group";
        devices?: DeviceReference[];
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"request">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"request">[];
        [k: string]: unknown;
    } & {
        type?: "group";
        devices?: DeviceReference<"request">[];
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"response">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"response">[];
        [k: string]: unknown;
    } & {
        type?: "group";
        devices?: DeviceReference<"response">[];
        [k: string]: unknown;
    } : never;
    type DeviceUpdate<T extends "request" | "response" | "all" = "all"> = T extends "all" ? ({
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference[];
        /**
         * List of users who own the device
         */
        owner?: UserReference[];
        [k: string]: unknown;
    } & {
        type?: "cloud instantiable";
        instantiateUrl?: string;
        services?: ServiceDescription[];
        [k: string]: unknown;
    }) | ({
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference[];
        /**
         * List of users who own the device
         */
        owner?: UserReference[];
        [k: string]: unknown;
    } & {
        type?: "device";
        experiment?: string;
        services?: ServiceDescription[];
        [k: string]: unknown;
    }) | ({
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference[];
        /**
         * List of users who own the device
         */
        owner?: UserReference[];
        [k: string]: unknown;
    } & {
        type?: "edge instantiable";
        codeUrl?: string;
        services?: ServiceDescription[];
        [k: string]: unknown;
    }) | ({
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference[];
        /**
         * List of users who own the device
         */
        owner?: UserReference[];
        [k: string]: unknown;
    } & {
        type?: "group";
        devices?: DeviceReference[];
        [k: string]: unknown;
    }) : T extends "request" ? ({
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"request">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"request">[];
        [k: string]: unknown;
    } & {
        type?: "cloud instantiable";
        instantiateUrl?: string;
        services?: ServiceDescription<"request">[];
        [k: string]: unknown;
    }) | ({
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"request">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"request">[];
        [k: string]: unknown;
    } & {
        type?: "device";
        experiment?: string;
        services?: ServiceDescription<"request">[];
        [k: string]: unknown;
    }) | ({
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"request">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"request">[];
        [k: string]: unknown;
    } & {
        type?: "edge instantiable";
        codeUrl?: string;
        services?: ServiceDescription<"request">[];
        [k: string]: unknown;
    }) | ({
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"request">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"request">[];
        [k: string]: unknown;
    } & {
        type?: "group";
        devices?: DeviceReference<"request">[];
        [k: string]: unknown;
    }) : T extends "response" ? ({
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"response">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"response">[];
        [k: string]: unknown;
    } & {
        type?: "cloud instantiable";
        instantiateUrl?: string;
        services?: ServiceDescription<"response">[];
        [k: string]: unknown;
    }) | ({
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"response">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"response">[];
        [k: string]: unknown;
    } & {
        type?: "device";
        experiment?: string;
        services?: ServiceDescription<"response">[];
        [k: string]: unknown;
    }) | ({
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"response">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"response">[];
        [k: string]: unknown;
    } & {
        type?: "edge instantiable";
        codeUrl?: string;
        services?: ServiceDescription<"response">[];
        [k: string]: unknown;
    }) | ({
        /**
         * Name of the device
         */
        name?: string;
        /**
         * Extended description of the device, features, etc.
         */
        description?: string;
        /**
         * Type of the device
         */
        type: "device" | "group" | "edge instantiable" | "cloud instantiable";
        /**
         * If true, the device may be seen and used by every user.
         */
        isPublic?: boolean;
        /**
         * List of users who can view the device
         */
        viewer?: UserReference<"response">[];
        /**
         * List of users who own the device
         */
        owner?: UserReference<"response">[];
        [k: string]: unknown;
    } & {
        type?: "group";
        devices?: DeviceReference<"response">[];
        [k: string]: unknown;
    }) : never;
    type AvailabilityRule<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        start?: string;
        end?: string;
        [k: string]: unknown;
    } & {
        available?: boolean;
        /**
         * If specified the time slot is repeated in a fixed offset specified by the frequency
         */
        repeat?: {
            frequency: "HOURLY" | "DAILY" | "WEEKLY";
            /**
             * Up to this date-time the time slot will be repeated.
             */
            until?: string;
            /**
             * How often the time slot will be repeated
             */
            count?: number;
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "request" ? {
        start?: string;
        end?: string;
        [k: string]: unknown;
    } & {
        available?: boolean;
        /**
         * If specified the time slot is repeated in a fixed offset specified by the frequency
         */
        repeat?: {
            frequency: "HOURLY" | "DAILY" | "WEEKLY";
            /**
             * Up to this date-time the time slot will be repeated.
             */
            until?: string;
            /**
             * How often the time slot will be repeated
             */
            count?: number;
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "response" ? {
        start?: string;
        end?: string;
        [k: string]: unknown;
    } & {
        available?: boolean;
        /**
         * If specified the time slot is repeated in a fixed offset specified by the frequency
         */
        repeat?: {
            frequency: "HOURLY" | "DAILY" | "WEEKLY";
            /**
             * Up to this date-time the time slot will be repeated.
             */
            until?: string;
            /**
             * How often the time slot will be repeated
             */
            count?: number;
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : never;
    type Message<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        messageType: string;
        [k: string]: unknown;
    } : T extends "request" ? {
        messageType: string;
        [k: string]: unknown;
    } : T extends "response" ? {
        messageType: string;
        [k: string]: unknown;
    } : never;
    type CommandMessage<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        messageType: string;
        [k: string]: unknown;
    } & {
        messageType: "command";
        command: string;
        [k: string]: unknown;
    } : T extends "request" ? {
        messageType: string;
        [k: string]: unknown;
    } & {
        messageType: "command";
        command: string;
        [k: string]: unknown;
    } : T extends "response" ? {
        messageType: string;
        [k: string]: unknown;
    } & {
        messageType: "command";
        command: string;
        [k: string]: unknown;
    } : never;
    type ServiceConfig<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        serviceType: string;
        serviceId: string;
        remoteServiceId: string;
        [k: string]: unknown;
    } : T extends "request" ? {
        serviceType: string;
        serviceId: string;
        remoteServiceId: string;
        [k: string]: unknown;
    } : T extends "response" ? {
        serviceType: string;
        serviceId: string;
        remoteServiceId: string;
        [k: string]: unknown;
    } : never;
    type CreatePeerconnectionMessage<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        messageType: string;
        [k: string]: unknown;
    } & {
        messageType: "command";
        command: string;
        [k: string]: unknown;
    } & {
        command: "createPeerconnection";
        connectionType: "webrtc" | "websocket" | "local";
        connectionUrl: string;
        services: ServiceConfig[];
        tiebreaker: boolean;
        config?: {
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "request" ? {
        messageType: string;
        [k: string]: unknown;
    } & {
        messageType: "command";
        command: string;
        [k: string]: unknown;
    } & {
        command: "createPeerconnection";
        connectionType: "webrtc" | "websocket" | "local";
        connectionUrl: string;
        services: ServiceConfig<"request">[];
        tiebreaker: boolean;
        config?: {
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "response" ? {
        messageType: string;
        [k: string]: unknown;
    } & {
        messageType: "command";
        command: string;
        [k: string]: unknown;
    } & {
        command: "createPeerconnection";
        connectionType: "webrtc" | "websocket" | "local";
        connectionUrl: string;
        services: ServiceConfig<"response">[];
        tiebreaker: boolean;
        config?: {
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : never;
    type ClosePeerconnectionMessage<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        messageType: string;
        [k: string]: unknown;
    } & {
        messageType: "command";
        command: string;
        [k: string]: unknown;
    } & {
        command: "closePeerconnection";
        connectionUrl: string;
        [k: string]: unknown;
    } : T extends "request" ? {
        messageType: string;
        [k: string]: unknown;
    } & {
        messageType: "command";
        command: string;
        [k: string]: unknown;
    } & {
        command: "closePeerconnection";
        connectionUrl: string;
        [k: string]: unknown;
    } : T extends "response" ? {
        messageType: string;
        [k: string]: unknown;
    } & {
        messageType: "command";
        command: string;
        [k: string]: unknown;
    } & {
        command: "closePeerconnection";
        connectionUrl: string;
        [k: string]: unknown;
    } : never;
    type SignalingMessage<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        messageType: string;
        [k: string]: unknown;
    } & {
        messageType: "signaling";
        signalingType: string;
        connectionUrl: string;
        content: {
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "request" ? {
        messageType: string;
        [k: string]: unknown;
    } & {
        messageType: "signaling";
        signalingType: string;
        connectionUrl: string;
        content: {
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "response" ? {
        messageType: string;
        [k: string]: unknown;
    } & {
        messageType: "signaling";
        signalingType: string;
        connectionUrl: string;
        content: {
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : never;
    type ConfigurationMessage<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        messageType: string;
        [k: string]: unknown;
    } & {
        messageType: "configuration";
        configuration: {
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "request" ? {
        messageType: string;
        [k: string]: unknown;
    } & {
        messageType: "configuration";
        configuration: {
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "response" ? {
        messageType: string;
        [k: string]: unknown;
    } & {
        messageType: "configuration";
        configuration: {
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : never;
    type ExperimentStatusChangedMessage<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        messageType: string;
        [k: string]: unknown;
    } & {
        messageType: "experiment-status-changed";
        status: string;
        message?: string;
        [k: string]: unknown;
    } : T extends "request" ? {
        messageType: string;
        [k: string]: unknown;
    } & {
        messageType: "experiment-status-changed";
        status: string;
        message?: string;
        [k: string]: unknown;
    } : T extends "response" ? {
        messageType: string;
        [k: string]: unknown;
    } & {
        messageType: "experiment-status-changed";
        status: string;
        message?: string;
        [k: string]: unknown;
    } : never;
    /**
* The status of the peerconnection.
*/
    type ConnectionStatus<T extends "request" | "response" | "all" = "all"> = T extends "all" ? "new" | "connecting" | "connected" | "disconnected" | "failed" | "closed" : T extends "request" ? "new" | "connecting" | "connected" | "disconnected" | "failed" | "closed" : T extends "response" ? "new" | "connecting" | "connected" | "disconnected" | "failed" | "closed" : never;
    type PeerconnectionCommon<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * URL of the peerconnection
         */
        url: string;
        /**
         * Type of the peerconnection
         */
        type: "local" | "webrtc";
        /**
         * The status of the peerconnection.
         */
        status: "new" | "connecting" | "connected" | "disconnected" | "failed" | "closed";
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * Type of the peerconnection
         */
        type: "local" | "webrtc";
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * URL of the peerconnection
         */
        url: string;
        /**
         * Type of the peerconnection
         */
        type: "local" | "webrtc";
        /**
         * The status of the peerconnection.
         */
        status: "new" | "connecting" | "connected" | "disconnected" | "failed" | "closed";
        [k: string]: unknown;
    } : never;
    type PeerconnectionOverview<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * URL of the peerconnection
         */
        url: string;
        /**
         * Type of the peerconnection
         */
        type: "local" | "webrtc";
        /**
         * The status of the peerconnection.
         */
        status: "new" | "connecting" | "connected" | "disconnected" | "failed" | "closed";
        [k: string]: unknown;
    } & {
        devices: SizedTuple<DeviceReference, 2, 2>;
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * Type of the peerconnection
         */
        type: "local" | "webrtc";
        [k: string]: unknown;
    } & {
        devices: SizedTuple<DeviceReference<"request">, 2, 2>;
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * URL of the peerconnection
         */
        url: string;
        /**
         * Type of the peerconnection
         */
        type: "local" | "webrtc";
        /**
         * The status of the peerconnection.
         */
        status: "new" | "connecting" | "connected" | "disconnected" | "failed" | "closed";
        [k: string]: unknown;
    } & {
        devices: SizedTuple<DeviceReference<"response">, 2, 2>;
        [k: string]: unknown;
    } : never;
    type ConfiguredDeviceReference<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * URL of the device
         */
        url: string;
        config?: {
            services?: ServiceConfig[];
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * URL of the device
         */
        url: string;
        config?: {
            services?: ServiceConfig<"request">[];
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * URL of the device
         */
        url: string;
        config?: {
            services?: ServiceConfig<"response">[];
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : never;
    type Peerconnection<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * URL of the peerconnection
         */
        url: string;
        /**
         * Type of the peerconnection
         */
        type: "local" | "webrtc";
        /**
         * The status of the peerconnection.
         */
        status: "new" | "connecting" | "connected" | "disconnected" | "failed" | "closed";
        [k: string]: unknown;
    } & {
        devices: SizedTuple<ConfiguredDeviceReference, 2, 2>;
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * Type of the peerconnection
         */
        type: "local" | "webrtc";
        [k: string]: unknown;
    } & {
        devices: SizedTuple<ConfiguredDeviceReference<"request">, 2, 2>;
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * URL of the peerconnection
         */
        url: string;
        /**
         * Type of the peerconnection
         */
        type: "local" | "webrtc";
        /**
         * The status of the peerconnection.
         */
        status: "new" | "connecting" | "connected" | "disconnected" | "failed" | "closed";
        [k: string]: unknown;
    } & {
        devices: SizedTuple<ConfiguredDeviceReference<"response">, 2, 2>;
        [k: string]: unknown;
    } : never;
    type PeerconnectionClosedEventCallback<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        callbackType: string;
        [k: string]: unknown;
    } & {
        callbackType: "event";
        eventType: string;
        [k: string]: unknown;
    } & {
        eventType: "peerconnection-closed";
        peerconnection: {
            /**
             * URL of the peerconnection
             */
            url: string;
            /**
             * Type of the peerconnection
             */
            type: "local" | "webrtc";
            /**
             * The status of the peerconnection.
             */
            status: "new" | "connecting" | "connected" | "disconnected" | "failed" | "closed";
            [k: string]: unknown;
        } & {
            devices: SizedTuple<ConfiguredDeviceReference, 2, 2>;
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "request" ? {
        callbackType: string;
        [k: string]: unknown;
    } & {
        callbackType: "event";
        eventType: string;
        [k: string]: unknown;
    } & {
        eventType: "peerconnection-closed";
        peerconnection: {
            /**
             * Type of the peerconnection
             */
            type: "local" | "webrtc";
            [k: string]: unknown;
        } & {
            devices: SizedTuple<ConfiguredDeviceReference<"request">, 2, 2>;
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "response" ? {
        callbackType: string;
        [k: string]: unknown;
    } & {
        callbackType: "event";
        eventType: string;
        [k: string]: unknown;
    } & {
        eventType: "peerconnection-closed";
        peerconnection: {
            /**
             * URL of the peerconnection
             */
            url: string;
            /**
             * Type of the peerconnection
             */
            type: "local" | "webrtc";
            /**
             * The status of the peerconnection.
             */
            status: "new" | "connecting" | "connected" | "disconnected" | "failed" | "closed";
            [k: string]: unknown;
        } & {
            devices: SizedTuple<ConfiguredDeviceReference<"response">, 2, 2>;
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : never;
    type PeerconnectionStatusChangedEventCallback<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        callbackType: string;
        [k: string]: unknown;
    } & {
        callbackType: "event";
        eventType: string;
        [k: string]: unknown;
    } & {
        eventType: "peerconnection-status-changed";
        peerconnection: {
            /**
             * URL of the peerconnection
             */
            url: string;
            /**
             * Type of the peerconnection
             */
            type: "local" | "webrtc";
            /**
             * The status of the peerconnection.
             */
            status: "new" | "connecting" | "connected" | "disconnected" | "failed" | "closed";
            [k: string]: unknown;
        } & {
            devices: SizedTuple<ConfiguredDeviceReference, 2, 2>;
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "request" ? {
        callbackType: string;
        [k: string]: unknown;
    } & {
        callbackType: "event";
        eventType: string;
        [k: string]: unknown;
    } & {
        eventType: "peerconnection-status-changed";
        peerconnection: {
            /**
             * Type of the peerconnection
             */
            type: "local" | "webrtc";
            [k: string]: unknown;
        } & {
            devices: SizedTuple<ConfiguredDeviceReference<"request">, 2, 2>;
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "response" ? {
        callbackType: string;
        [k: string]: unknown;
    } & {
        callbackType: "event";
        eventType: string;
        [k: string]: unknown;
    } & {
        eventType: "peerconnection-status-changed";
        peerconnection: {
            /**
             * URL of the peerconnection
             */
            url: string;
            /**
             * Type of the peerconnection
             */
            type: "local" | "webrtc";
            /**
             * The status of the peerconnection.
             */
            status: "new" | "connecting" | "connected" | "disconnected" | "failed" | "closed";
            [k: string]: unknown;
        } & {
            devices: SizedTuple<ConfiguredDeviceReference<"response">, 2, 2>;
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : never;
    function isDeviceOverview<T extends "request" | "response" | "all" = "all">(obj: unknown, type?: "request" | "response" | "all" | T): obj is DeviceOverview<T>;
    function isInstantiableCloudDevice<T extends "request" | "response" | "all" = "all">(obj: unknown, type?: "request" | "response" | "all" | T): obj is InstantiableCloudDevice<T>;
    function isConcreteDevice<T extends "request" | "response" | "all" = "all">(obj: unknown, type?: "request" | "response" | "all" | T): obj is ConcreteDevice<T>;
    function isInstantiableBrowserDevice<T extends "request" | "response" | "all" = "all">(obj: unknown, type?: "request" | "response" | "all" | T): obj is InstantiableBrowserDevice<T>;
    function isDeviceGroup<T extends "request" | "response" | "all" = "all">(obj: unknown, type?: "request" | "response" | "all" | T): obj is DeviceGroup<T>;
    function isDevice<T extends "request" | "response" | "all" = "all">(obj: unknown, type?: "request" | "response" | "all" | T): obj is Device<T>;
    function isCallback<T extends "request" | "response" | "all" = "all">(obj: unknown, type?: "request" | "response" | "all" | T): obj is Callback<T>;
    function isEventCallback<T extends "request" | "response" | "all" = "all">(obj: unknown, type?: "request" | "response" | "all" | T): obj is EventCallback<T>;
    function isDeviceChangedEventCallback<T extends "request" | "response" | "all" = "all">(obj: unknown, type?: "request" | "response" | "all" | T): obj is DeviceChangedEventCallback<T>;
    function isMessage<T extends "request" | "response" | "all" = "all">(obj: unknown, type?: "request" | "response" | "all" | T): obj is Message<T>;
    function isCommandMessage<T extends "request" | "response" | "all" = "all">(obj: unknown, type?: "request" | "response" | "all" | T): obj is CommandMessage<T>;
    function isCreatePeerconnectionMessage<T extends "request" | "response" | "all" = "all">(obj: unknown, type?: "request" | "response" | "all" | T): obj is CreatePeerconnectionMessage<T>;
    function isClosePeerconnectionMessage<T extends "request" | "response" | "all" = "all">(obj: unknown, type?: "request" | "response" | "all" | T): obj is ClosePeerconnectionMessage<T>;
    function isSignalingMessage<T extends "request" | "response" | "all" = "all">(obj: unknown, type?: "request" | "response" | "all" | T): obj is SignalingMessage<T>;
    function isConfigurationMessage<T extends "request" | "response" | "all" = "all">(obj: unknown, type?: "request" | "response" | "all" | T): obj is ConfigurationMessage<T>;
    function isExperimentStatusChangedMessage<T extends "request" | "response" | "all" = "all">(obj: unknown, type?: "request" | "response" | "all" | T): obj is ExperimentStatusChangedMessage<T>;
    function isPeerconnection<T extends "request" | "response" | "all" = "all">(obj: unknown, type?: "request" | "response" | "all" | T): obj is Peerconnection<T>;
    function isPeerconnectionClosedEventCallback<T extends "request" | "response" | "all" = "all">(obj: unknown, type?: "request" | "response" | "all" | T): obj is PeerconnectionClosedEventCallback<T>;
    function isPeerconnectionStatusChangedEventCallback<T extends "request" | "response" | "all" = "all">(obj: unknown, type?: "request" | "response" | "all" | T): obj is PeerconnectionStatusChangedEventCallback<T>;
}
/**
 * Namespace containing the types for the Experiment Service.
 */
export declare namespace ExperimentServiceTypes {
    type ExperimentOverview<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * URL of the experiment
         */
        url: string;
        status: "created" | "booked" | "setup" | "running" | "finished" | "created" | "booked" | "running" | "finished";
        [k: string]: unknown;
    } : T extends "request" ? {
        status: "created" | "booked" | "running" | "finished";
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * URL of the experiment
         */
        url: string;
        status: "created" | "booked" | "setup" | "running" | "finished";
        [k: string]: unknown;
    } : never;
    type Device<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * URL to the [device](https://cross-lab-project.github.io/crosslab/api/device.html#get-/devices/-device_id-).
         */
        device: string;
        /**
         * The name of the device's role.
         */
        role: string;
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * URL to the [device](https://cross-lab-project.github.io/crosslab/api/device.html#get-/devices/-device_id-).
         */
        device: string;
        /**
         * The name of the device's role.
         */
        role: string;
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * URL to the [device](https://cross-lab-project.github.io/crosslab/api/device.html#get-/devices/-device_id-).
         */
        device: string;
        /**
         * The name of the device's role.
         */
        role: string;
        [k: string]: unknown;
    } : never;
    type Role<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * Name for an experiment role.
         */
        name: string;
        description?: string;
        /**
         * Configuration for all devices with this role.
         */
        configuration?: {
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * Name for an experiment role.
         */
        name: string;
        description?: string;
        /**
         * Configuration for all devices with this role.
         */
        configuration?: {
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * Name for an experiment role.
         */
        name: string;
        description?: string;
        /**
         * Configuration for all devices with this role.
         */
        configuration?: {
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : never;
    type Participant<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * The name of the participant's role.
         */
        role?: string;
        serviceId?: string;
        /**
         * Service configuration of the participant.
         *
         * This configuration object will be merged with the service configuration to become the service configuration send to the participant (fields of the participant configuration override the service configuration).
         *
         */
        config?: {
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * The name of the participant's role.
         */
        role?: string;
        serviceId?: string;
        /**
         * Service configuration of the participant.
         *
         * This configuration object will be merged with the service configuration to become the service configuration send to the participant (fields of the participant configuration override the service configuration).
         *
         */
        config?: {
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * The name of the participant's role.
         */
        role?: string;
        serviceId?: string;
        /**
         * Service configuration of the participant.
         *
         * This configuration object will be merged with the service configuration to become the service configuration send to the participant (fields of the participant configuration override the service configuration).
         *
         */
        config?: {
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : never;
    type ServiceConfiguration<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * Type of the service
         */
        serviceType?: string;
        /**
         * Configuration of the service
         *
         * This configuration object will be merged with the participant configuration to become the service configuration send to the participant (fields of the participant configuration override the service configuration).
         *
         */
        configuration?: {
            [k: string]: unknown;
        };
        /**
         * List of participants for the service
         */
        participants?: Participant[];
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * Type of the service
         */
        serviceType?: string;
        /**
         * Configuration of the service
         *
         * This configuration object will be merged with the participant configuration to become the service configuration send to the participant (fields of the participant configuration override the service configuration).
         *
         */
        configuration?: {
            [k: string]: unknown;
        };
        /**
         * List of participants for the service
         */
        participants?: Participant<"request">[];
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * Type of the service
         */
        serviceType?: string;
        /**
         * Configuration of the service
         *
         * This configuration object will be merged with the participant configuration to become the service configuration send to the participant (fields of the participant configuration override the service configuration).
         *
         */
        configuration?: {
            [k: string]: unknown;
        };
        /**
         * List of participants for the service
         */
        participants?: Participant<"response">[];
        [k: string]: unknown;
    } : never;
    type Experiment<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * URL of the experiment
         */
        url: string;
        status: "created" | "booked" | "setup" | "running" | "finished" | "created" | "booked" | "running" | "finished";
        [k: string]: unknown;
    } & {
        bookingTime?: {
            startTime?: string;
            endTime?: string;
            [k: string]: unknown;
        };
        /**
         * Devices associated with the experiment
         */
        devices: Device[];
        /**
         * Roles that are used in this experiment
         */
        roles: Role[];
        /**
         * Connections associated with the experiment
         */
        connections: string[];
        /**
         * Services associated with the experiment
         */
        serviceConfigurations: ServiceConfiguration[];
        /**
         * Instantiated devices that need to be started by the user.
         */
        instantiatedDevices: {
            codeUrl: string;
            url: string;
            token: string;
            instanceOf: string;
            [k: string]: unknown;
        }[];
        [k: string]: unknown;
    } : T extends "request" ? {
        status: "created" | "booked" | "running" | "finished";
        [k: string]: unknown;
    } & {
        bookingTime?: {
            startTime?: string;
            endTime?: string;
            [k: string]: unknown;
        };
        /**
         * Devices associated with the experiment
         */
        devices: Device<"request">[];
        /**
         * Roles that are used in this experiment
         */
        roles: Role<"request">[];
        /**
         * Services associated with the experiment
         */
        serviceConfigurations: ServiceConfiguration<"request">[];
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * URL of the experiment
         */
        url: string;
        status: "created" | "booked" | "setup" | "running" | "finished";
        [k: string]: unknown;
    } & {
        bookingTime?: {
            startTime?: string;
            endTime?: string;
            [k: string]: unknown;
        };
        /**
         * Devices associated with the experiment
         */
        devices: Device<"response">[];
        /**
         * Roles that are used in this experiment
         */
        roles: Role<"response">[];
        /**
         * Connections associated with the experiment
         */
        connections: string[];
        /**
         * Services associated with the experiment
         */
        serviceConfigurations: ServiceConfiguration<"response">[];
        /**
         * Instantiated devices that need to be started by the user.
         */
        instantiatedDevices: {
            codeUrl: string;
            url: string;
            token: string;
            instanceOf: string;
            [k: string]: unknown;
        }[];
        [k: string]: unknown;
    } : never;
    type Callback<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        callbackType: string;
        [k: string]: unknown;
    } : T extends "request" ? {
        callbackType: string;
        [k: string]: unknown;
    } : T extends "response" ? {
        callbackType: string;
        [k: string]: unknown;
    } : never;
    type EventCallback<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        callbackType: string;
        [k: string]: unknown;
    } & {
        callbackType: "event";
        eventType: string;
        [k: string]: unknown;
    } : T extends "request" ? {
        callbackType: string;
        [k: string]: unknown;
    } & {
        callbackType: "event";
        eventType: string;
        [k: string]: unknown;
    } : T extends "response" ? {
        callbackType: string;
        [k: string]: unknown;
    } & {
        callbackType: "event";
        eventType: string;
        [k: string]: unknown;
    } : never;
    type ExperimentChangedEventCallback<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        callbackType: string;
        [k: string]: unknown;
    } & {
        callbackType: "event";
        eventType: string;
        [k: string]: unknown;
    } & {
        eventType: "experiment-changed";
        experiment: {
            /**
             * URL of the experiment
             */
            url: string;
            status: "created" | "booked" | "setup" | "running" | "finished" | "created" | "booked" | "running" | "finished";
            [k: string]: unknown;
        } & {
            bookingTime?: {
                startTime?: string;
                endTime?: string;
                [k: string]: unknown;
            };
            /**
             * Devices associated with the experiment
             */
            devices: Device[];
            /**
             * Roles that are used in this experiment
             */
            roles: Role[];
            /**
             * Connections associated with the experiment
             */
            connections: string[];
            /**
             * Services associated with the experiment
             */
            serviceConfigurations: ServiceConfiguration[];
            /**
             * Instantiated devices that need to be started by the user.
             */
            instantiatedDevices: {
                codeUrl: string;
                url: string;
                token: string;
                instanceOf: string;
                [k: string]: unknown;
            }[];
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "request" ? {
        callbackType: string;
        [k: string]: unknown;
    } & {
        callbackType: "event";
        eventType: string;
        [k: string]: unknown;
    } & {
        eventType: "experiment-changed";
        experiment: {
            status: "created" | "booked" | "running" | "finished";
            [k: string]: unknown;
        } & {
            bookingTime?: {
                startTime?: string;
                endTime?: string;
                [k: string]: unknown;
            };
            /**
             * Devices associated with the experiment
             */
            devices: Device<"request">[];
            /**
             * Roles that are used in this experiment
             */
            roles: Role<"request">[];
            /**
             * Services associated with the experiment
             */
            serviceConfigurations: ServiceConfiguration<"request">[];
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "response" ? {
        callbackType: string;
        [k: string]: unknown;
    } & {
        callbackType: "event";
        eventType: string;
        [k: string]: unknown;
    } & {
        eventType: "experiment-changed";
        experiment: {
            /**
             * URL of the experiment
             */
            url: string;
            status: "created" | "booked" | "setup" | "running" | "finished";
            [k: string]: unknown;
        } & {
            bookingTime?: {
                startTime?: string;
                endTime?: string;
                [k: string]: unknown;
            };
            /**
             * Devices associated with the experiment
             */
            devices: Device<"response">[];
            /**
             * Roles that are used in this experiment
             */
            roles: Role<"response">[];
            /**
             * Connections associated with the experiment
             */
            connections: string[];
            /**
             * Services associated with the experiment
             */
            serviceConfigurations: ServiceConfiguration<"response">[];
            /**
             * Instantiated devices that need to be started by the user.
             */
            instantiatedDevices: {
                codeUrl: string;
                url: string;
                token: string;
                instanceOf: string;
                [k: string]: unknown;
            }[];
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : never;
    type ExperimentOverviewUpdate<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        status?: "created" | "booked" | "setup" | "running" | "finished" | "created" | "booked" | "running" | "finished";
        [k: string]: unknown;
    } : T extends "request" ? {
        status?: "created" | "booked" | "running" | "finished";
        [k: string]: unknown;
    } : T extends "response" ? {
        status?: "created" | "booked" | "setup" | "running" | "finished";
        [k: string]: unknown;
    } : never;
    type ExperimentUpdate<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        status?: "created" | "booked" | "setup" | "running" | "finished" | "created" | "booked" | "running" | "finished";
        [k: string]: unknown;
    } & {
        bookingTime?: {
            startTime?: string;
            endTime?: string;
            [k: string]: unknown;
        };
        /**
         * Devices associated with the experiment
         */
        devices?: Device[];
        /**
         * Roles that are used in this experiment
         */
        roles?: Role[];
        /**
         * Services associated with the experiment
         */
        serviceConfigurations?: ServiceConfiguration[];
        [k: string]: unknown;
    } : T extends "request" ? {
        status?: "created" | "booked" | "running" | "finished";
        [k: string]: unknown;
    } & {
        bookingTime?: {
            startTime?: string;
            endTime?: string;
            [k: string]: unknown;
        };
        /**
         * Devices associated with the experiment
         */
        devices?: Device<"request">[];
        /**
         * Roles that are used in this experiment
         */
        roles?: Role<"request">[];
        /**
         * Services associated with the experiment
         */
        serviceConfigurations?: ServiceConfiguration<"request">[];
        [k: string]: unknown;
    } : T extends "response" ? {
        status?: "created" | "booked" | "setup" | "running" | "finished";
        [k: string]: unknown;
    } & {
        bookingTime?: {
            startTime?: string;
            endTime?: string;
            [k: string]: unknown;
        };
        /**
         * Devices associated with the experiment
         */
        devices?: Device<"response">[];
        /**
         * Roles that are used in this experiment
         */
        roles?: Role<"response">[];
        /**
         * Services associated with the experiment
         */
        serviceConfigurations?: ServiceConfiguration<"response">[];
        [k: string]: unknown;
    } : never;
    type TemplateOverview<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * URL of the template
         */
        url: string;
        /**
         * Name of the template
         */
        name: string;
        /**
         * Description of the template
         */
        description?: string;
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * Name of the template
         */
        name: string;
        /**
         * Description of the template
         */
        description?: string;
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * URL of the template
         */
        url: string;
        /**
         * Name of the template
         */
        name: string;
        /**
         * Description of the template
         */
        description?: string;
        [k: string]: unknown;
    } : never;
    type Template<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * URL of the template
         */
        url: string;
        /**
         * Name of the template
         */
        name: string;
        /**
         * Description of the template
         */
        description?: string;
        [k: string]: unknown;
    } & {
        /**
         * Configuration of the templated experiment
         */
        configuration: {
            /**
             * Devices associated with the templated experiment
             */
            devices: Device[];
            /**
             * Roles that are used in this templated experiment
             */
            roles: Role[];
            /**
             * Services associated with the templated experiment
             */
            serviceConfigurations: ServiceConfiguration[];
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * Name of the template
         */
        name: string;
        /**
         * Description of the template
         */
        description?: string;
        [k: string]: unknown;
    } & {
        /**
         * Configuration of the templated experiment
         */
        configuration: {
            /**
             * Devices associated with the templated experiment
             */
            devices: Device<"request">[];
            /**
             * Roles that are used in this templated experiment
             */
            roles: Role<"request">[];
            /**
             * Services associated with the templated experiment
             */
            serviceConfigurations: ServiceConfiguration<"request">[];
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * URL of the template
         */
        url: string;
        /**
         * Name of the template
         */
        name: string;
        /**
         * Description of the template
         */
        description?: string;
        [k: string]: unknown;
    } & {
        /**
         * Configuration of the templated experiment
         */
        configuration: {
            /**
             * Devices associated with the templated experiment
             */
            devices: Device<"response">[];
            /**
             * Roles that are used in this templated experiment
             */
            roles: Role<"response">[];
            /**
             * Services associated with the templated experiment
             */
            serviceConfigurations: ServiceConfiguration<"response">[];
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : never;
    type TemplateUpdate<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * Name of the template
         */
        name?: string;
        /**
         * Description of the template
         */
        description?: string;
        /**
         * Configuration of the templated experiment
         */
        configuration?: {
            /**
             * Devices associated with the templated experiment
             */
            devices?: Device[];
            /**
             * Roles that are used in this templated experiment
             */
            roles?: Role[];
            /**
             * Services associated with the templated experiment
             */
            serviceConfigurations?: ServiceConfiguration[];
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * Name of the template
         */
        name?: string;
        /**
         * Description of the template
         */
        description?: string;
        /**
         * Configuration of the templated experiment
         */
        configuration?: {
            /**
             * Devices associated with the templated experiment
             */
            devices?: Device<"request">[];
            /**
             * Roles that are used in this templated experiment
             */
            roles?: Role<"request">[];
            /**
             * Services associated with the templated experiment
             */
            serviceConfigurations?: ServiceConfiguration<"request">[];
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * Name of the template
         */
        name?: string;
        /**
         * Description of the template
         */
        description?: string;
        /**
         * Configuration of the templated experiment
         */
        configuration?: {
            /**
             * Devices associated with the templated experiment
             */
            devices?: Device<"response">[];
            /**
             * Roles that are used in this templated experiment
             */
            roles?: Role<"response">[];
            /**
             * Services associated with the templated experiment
             */
            serviceConfigurations?: ServiceConfiguration<"response">[];
            [k: string]: unknown;
        };
        [k: string]: unknown;
    } : never;
    function isCallback<T extends "request" | "response" | "all" = "all">(obj: unknown, type?: "request" | "response" | "all" | T): obj is Callback<T>;
    function isEventCallback<T extends "request" | "response" | "all" = "all">(obj: unknown, type?: "request" | "response" | "all" | T): obj is EventCallback<T>;
    function isExperimentChangedEventCallback<T extends "request" | "response" | "all" = "all">(obj: unknown, type?: "request" | "response" | "all" | T): obj is ExperimentChangedEventCallback<T>;
}
/**
 * Namespace containing the types for the Federation Service.
 */
export declare namespace FederationServiceTypes {
    type Institution<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        url: string;
        name?: string;
        homepage?: string;
        api?: string;
        apiToken?: string;
        [k: string]: unknown;
    } : T extends "request" ? {
        name?: string;
        homepage?: string;
        api?: string;
        apiToken?: string;
        [k: string]: unknown;
    } : T extends "response" ? {
        url: string;
        name?: string;
        homepage?: string;
        api?: string;
        [k: string]: unknown;
    } : never;
}
/**
 * Namespace containing the types for the Booking Service.
 */
export declare namespace BookingServiceTypes {
    /**
* A device might either be a physical/virtual device or a group of device.
*/
    type Device<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * Unique ID of the device. Contains the institution (by having an end point at that institution)
         */
        ID: string;
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * Unique ID of the device. Contains the institution (by having an end point at that institution)
         */
        ID: string;
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * Unique ID of the device. Contains the institution (by having an end point at that institution)
         */
        ID: string;
        [k: string]: unknown;
    } : never;
    /**
* An experiment describes a set of devices and how they should be connected (potentially among other metadata).
*/
    type Experiment<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * List of devices used in experiment.
         */
        Devices: Device[];
        /**
         * User provided description, for example might be a reason for the booking (e.g. maintenance) or a link to the experiment. Might be empty or missing.
         *
         */
        Description?: string;
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * List of devices used in experiment.
         */
        Devices: Device<"request">[];
        /**
         * User provided description, for example might be a reason for the booking (e.g. maintenance) or a link to the experiment. Might be empty or missing.
         *
         */
        Description?: string;
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * List of devices used in experiment.
         */
        Devices: Device<"response">[];
        /**
         * User provided description, for example might be a reason for the booking (e.g. maintenance) or a link to the experiment. Might be empty or missing.
         *
         */
        Description?: string;
        [k: string]: unknown;
    } : never;
    /**
* A time slot represents a slice of time used for bookings.
*/
    type Timeslot<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * Start time of the booking.
         */
        Start: string;
        /**
         * End time of the booking.
         */
        End: string;
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * Start time of the booking.
         */
        Start: string;
        /**
         * End time of the booking.
         */
        End: string;
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * Start time of the booking.
         */
        Start: string;
        /**
         * End time of the booking.
         */
        End: string;
        [k: string]: unknown;
    } : never;
    /**
* A booking in the booking system.
*/
    type Booking<T extends "request" | "response" | "all" = "all"> = T extends "all" ? {
        /**
         * Unique ID of the booking.
         */
        ID: string;
        /**
         * A time slot represents a slice of time used for bookings.
         */
        Time: {
            /**
             * Start time of the booking.
             */
            Start: string;
            /**
             * End time of the booking.
             */
            End: string;
            [k: string]: unknown;
        };
        Devices: string[];
        /**
         * Type of booking. Currently, only one type is defined, but others might follow (e.g. priority booking). If empty, 'normal' is assumed.
         */
        Type?: "normal";
        /**
         * Current status of the booking. While the booking is pending, it can not be used. Will change automatically and can not be set by user. 'rejected' is set when the initial booking failed, 'cancelled' when the booking was deleted / cancelled after it was once active. The 'active-*' will be used when a device was added after the booking was locked.
         *
         */
        Status: "pending" | "booked" | "rejected" | "cancelled" | "active" | "active-pending" | "active-rejected";
        /**
         * If true, this booking was done by you.
         */
        You: boolean;
        /**
         * Shows whether the booking was done by an external institution.
         */
        External: boolean;
        /**
         * User readable notes about the status of the booking (e.g. if devices are unknown).
         */
        Message?: string;
        [k: string]: unknown;
    } : T extends "request" ? {
        /**
         * Unique ID of the booking.
         */
        ID: string;
        /**
         * A time slot represents a slice of time used for bookings.
         */
        Time: {
            /**
             * Start time of the booking.
             */
            Start: string;
            /**
             * End time of the booking.
             */
            End: string;
            [k: string]: unknown;
        };
        Devices: string[];
        /**
         * Type of booking. Currently, only one type is defined, but others might follow (e.g. priority booking). If empty, 'normal' is assumed.
         */
        Type?: "normal";
        /**
         * Current status of the booking. While the booking is pending, it can not be used. Will change automatically and can not be set by user. 'rejected' is set when the initial booking failed, 'cancelled' when the booking was deleted / cancelled after it was once active. The 'active-*' will be used when a device was added after the booking was locked.
         *
         */
        Status: "pending" | "booked" | "rejected" | "cancelled" | "active" | "active-pending" | "active-rejected";
        /**
         * If true, this booking was done by you.
         */
        You: boolean;
        /**
         * Shows whether the booking was done by an external institution.
         */
        External: boolean;
        /**
         * User readable notes about the status of the booking (e.g. if devices are unknown).
         */
        Message?: string;
        [k: string]: unknown;
    } : T extends "response" ? {
        /**
         * Unique ID of the booking.
         */
        ID: string;
        /**
         * A time slot represents a slice of time used for bookings.
         */
        Time: {
            /**
             * Start time of the booking.
             */
            Start: string;
            /**
             * End time of the booking.
             */
            End: string;
            [k: string]: unknown;
        };
        Devices: string[];
        /**
         * Type of booking. Currently, only one type is defined, but others might follow (e.g. priority booking). If empty, 'normal' is assumed.
         */
        Type?: "normal";
        /**
         * Current status of the booking. While the booking is pending, it can not be used. Will change automatically and can not be set by user. 'rejected' is set when the initial booking failed, 'cancelled' when the booking was deleted / cancelled after it was once active. The 'active-*' will be used when a device was added after the booking was locked.
         *
         */
        Status: "pending" | "booked" | "rejected" | "cancelled" | "active" | "active-pending" | "active-rejected";
        /**
         * If true, this booking was done by you.
         */
        You: boolean;
        /**
         * Shows whether the booking was done by an external institution.
         */
        External: boolean;
        /**
         * User readable notes about the status of the booking (e.g. if devices are unknown).
         */
        Message?: string;
        [k: string]: unknown;
    } : never;
}
export {};
//# sourceMappingURL=types.d.ts.map